/*************************************************************
 * adc_main.c
 *
 * ADC main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2009. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <s1c176xx.h>
#include <string.h>

#ifdef	PE_ADC
#include <adc_api.h>
#include <mux_api.h>

#define	ADC_MAIN_LOOP_CT_MAX	10U						// loop counter max

static unsigned short	adcBufCounter[ADC_MAIN_LOOP_CT_MAX + 1] = {0};	// counter record buffer
static volatile unsigned char	adcLoopCt;							// loop counter

/* prototype */
void adcMain(void);
static void startADC(void);
static void stopADC(void);
void adcIntHandler(void)__attribute__((interrupt_handler));

/*
 * A/D converter sample program.
 * param	void
 * return	void
 * history	:	2009/05/11
 */
void adcMain(void)
{
	printf("<<< AD converter demonstration start >>>\n");

	// start ADC
	startADC();

	// set software trigger
	ADC_controlTrigger(ADC_CONTROL_START);

	adcLoopCt = 0U;
	while(adcLoopCt < ADC_MAIN_LOOP_CT_MAX) {
		asm( "halt" );
		asm( "nop" );
		adcLoopCt++;	// counter increment after wakeup
	}

	// stop ADC
	stopADC();

	// clear ports
	MUX_setADCport(MUX_ADTRG_ON, ADC_CH0, ADC_CH0, MUX_OFF);

	// display result
	adcLoopCt = 0;
	while(adcLoopCt < ADC_MAIN_LOOP_CT_MAX) {
		adcLoopCt++;
		printf("AD conversion result : %04x\n", adcBufCounter[adcLoopCt - 1U]);
	}

	printf("<<< AD converter demonstration finish >>>\n");
}

/*
 * Start A/D conversion .
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void startADC(void)
{
	ADC_INIT_PARAM 		param;											// initialize parameter

	param.endCh		=	ADC_CH0;
	param.startCh	=	ADC_CH0;
	param.storeMode	=	ADC_STORE_MODE0;
	param.convMode	=	ADC_CONVMODE_CONTINUOUS;
	param.convTrig	=	ADC_CONVTRIG_SOFT;
	param.smpClock	=	ADC_SAMPLING_CLOCK4;
	param.convClock	=	ADC_CONVCLK2;
	ADC_init(&param);

	ADC_initInt(ADC_INT_LEVEL3);
	ADC_controlInt(ADC_OVWINT_DISABLE | ADC_COMPINT_ENABLE);
	ADC_setEnable(ADC_ENABLE);

}

/*
 * Stop A/D conversion.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void stopADC(void)
{
	ADC_controlTrigger(ADC_CONTROL_STOP);

	ADC_setEnable(ADC_DISABLE);
	ADC_controlInt(ADC_OVWINT_DISABLE | ADC_COMPINT_DISABLE);
	ADC_initInt(ADC_INT_LEVEL0);
}

/*
 * Completed A/D conversion interrupt handler.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void adcIntHandler(void)
{
	unsigned short compflag;	// interrupt flag

	// get interrupt flag
	ADC_checkIntFlag(&compflag);

	if((compflag & ADC_COMPINT_OCCURRED) == ADC_COMPINT_OCCURRED) {
		// get ADC result & reset interrupt flag
		ADC_getResult(&adcBufCounter[adcLoopCt]);
	}
}

#endif	// end of PE_ADC
