/*************************************************************
 * current_main.c
 *
 * current measurement main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2010. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <s1c176xx.h>

#ifdef	PE_CURRENT_MEASURE
#include <osc_api.h>
#include <port_api.h>
#include <mux_api.h>
#include <clg_api.h>
#include "main.h"

#ifdef	PE_VD1
#include <vd1_api.h>
#endif

// prototype
void currentMeasurementMain(unsigned char mode);
static void startIOSC(void);
static void goSleep(void);
static void goHaltCPUOSC1(void);
static void goHaltCPUOSC1_3(void);
static void goHaltCPUOSC1_3_I(void);


// sub menu table
static MENU_TBL currentMainMenu[] = {
	{ "Sleep                "	, goSleep					},
	{ "Halt with OSC1       "	, goHaltCPUOSC1				},
	{ "Halt with OSC1/3     "	, goHaltCPUOSC1_3			},
	{ "Halt with OSC1/3/IOSC"	, goHaltCPUOSC1_3_I			},
	{ NULL						, NULL						}
};

/*
 * sample program for current measurement
 * param	unsigned char  mode    Measurement mode.
 * return	void
 * history	:	2009/12/25
 *          :   2010/08/06 change for auto running current measure program
 */
void currentMeasurementMain(unsigned char mode)
{
	// port all off
	MUX_init();
	PORT_init();

	// IOSC start
	startIOSC();

	// select peripheral test
	currentMainMenu[mode].function();
}

/*
 * start all OSC(OSC1, OSC3, IOSC).
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void startIOSC(void)
{
	CLG_OSC_setWaitCycle(CLG_OSC_SELIOSC_64, CLG_OSC_SELOSC3_512);			// set wait cycle
	CLG_OSC_controlOscillation(CLG_OSC_IOSC_ENABLE | CLG_OSC_OSC1_ENABLE | CLG_OSC_OSC3_ENABLE);	// start all OSC
}

/*
 * sleep CPU
 * param	void
 * return	void
 * history	:	2009/04/12
 */
static void goSleep(void)
{

#ifdef	PE_VD1
	VD1_setMode( VD1_OFF );			// heavy load protection mode disable
#endif
	while(1) {
		asm ( "slp" );
		asm ( "nop" );
	}
#ifdef	PE_VD1
	VD1_setMode( VD1_ON );			// heavy load protection mode enable
#endif
}

/*
 * change OSC3 to OSC1 and stop IOSC and OSC3, halt CPU
 * this function must be called when OSC3 and OSC1 are active
 * param	void
 * return	void
 * history	:	2009/12/25
 * 				2010/04/12 add PCLK Control
 */
static void goHaltCPUOSC1(void)
{
	CLG_OSC_setClockSource(CLG_OSC_SELHSCLK_OSC3, CLG_OSC_SELCLKSRC_OSC1);	// change clock source
	CLG_OSC_controlOscillation(CLG_OSC_IOSC_DISABLE | CLG_OSC_OSC1_ENABLE | CLG_OSC_OSC3_DISABLE);	// stop IOSC & OSC3

#ifdef	PE_VD1
	VD1_setMode( VD1_OFF );			// heavy load protection mode disable
#endif

	// PCLK disable.
	CLG_setPCLKEnable(CLG_PCLK_DISABLE);

	while(1) {
		asm( "halt" );
		asm( "nop" );
	}

	// PCLK enable.
	CLG_setPCLKEnable(CLG_PCLK_ENABLE);

#ifdef	PE_VD1
	VD1_setMode( VD1_ON );			// heavy load protection mode enable
#endif
}

/*
 * stop IOSC and halt CPU
 * this function must be called when OSC3 and OSC1 are active
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void goHaltCPUOSC1_3(void)
{
	CLG_OSC_controlOscillation(CLG_OSC_IOSC_DISABLE | CLG_OSC_OSC1_ENABLE | CLG_OSC_OSC3_ENABLE);	// stop IOSC
	while(1)
	{
		asm( "halt" );
		asm( "nop" );
	}
}

/*
 * halt CPU
 * this function must be called when OSC3 and OSC1, IOSC is active
 * param	void
 * return	void
 * history	:	2009/12/25
 * 				2010/07/16 change to loop
 */
static void goHaltCPUOSC1_3_I(void)
{
	while(1)
	{
		asm( "halt" );
		asm( "nop" );
	}
}

#endif	// end of PE_CURRENT_MEASURE
