/*************************************************************
 * port_main.c
 *
 * PORT main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2009. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <s1c176xx.h>

#ifdef	PE_PORT
#include <port_api.h>

// port output paterns
#define	PORT_MAIN_PORT_OUT_HIGH	(PORT_BIT_X0 | PORT_BIT_X1)
#define	PORT_MAIN_PORT_OUT_LOW	(0)

// bit shift
#define	PORT_BIT(x)		((unsigned char)(1 << (x)))

// Pxx port output level
static unsigned char	flgP1xOut;			// P1x port output status

// port end info
#define	END_KEYNO		(3)
volatile static unsigned char	endFlag;

// prototype
void portMain(void);
static void setPortInput(void);
static void setPortOutput(void);
static void clearPortInput(void);
static void clearPortOutput(void);
void portSetCallBackFunc(unsigned char chNo, void(*name)(void));
void portClearCallBackFunc(unsigned char chNo);
void portIntP0xHandler(void)__attribute__((interrupt_handler));
void portIntP1xHandler(void)__attribute__((interrupt_handler));

static void ((*callBackFunction[PORT_INT_MAX+1U])(void));	// call back function

/*
 * PORT sample program
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void portMain(void)
{
	unsigned char	i;

	printf("<<< Port demonstration start >>>\n\n");
	
	for(i = 0; i < PORT_INT_MAX; i++) {
		callBackFunction[i] = 0U;
	}

	// set ports to a input mode
	setPortInput();

	// set ports to a output mode
	setPortOutput();


	// wait end flag
	endFlag = 0;
	while(1) {
		asm("halt");
		asm("nop");
		
		if(endFlag == 1) {
			break;
		}
	}

	// clear output port settings
	clearPortOutput();

	// clear input port settings
	clearPortInput();

	printf("<<< Port demonstration finish >>>\n\n");
}


/*
 * set registers for interrupt inputs.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void setPortInput(void)
{
	// set input settings
	PORT_setChatteringFilter(PORT_CHATNO_P030, PORT_CHATTIME_16384);
	PORT_setChatteringFilter(PORT_CHATNO_P174, PORT_CHATTIME_16384);

	PORT_controlPullup(PORT_NO_P0, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);
	PORT_controlPullup(PORT_NO_P1, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);

	PORT_controlSchmittTrigger(PORT_NO_P0, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);
	PORT_controlSchmittTrigger(PORT_NO_P1, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);

	PORT_controlOutput(PORT_NO_P0, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
	PORT_controlOutput(PORT_NO_P1, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);

	PORT_controlInput(PORT_NO_P0, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);
	PORT_controlInput(PORT_NO_P1, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);

	PORT_setIntEdge(PORT_NO_P0, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
	PORT_setIntEdge(PORT_NO_P1, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_ENABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);

	PORT_initInt(PORT_NO_P0, PORT_INT_LEVEL3);
	PORT_initInt(PORT_NO_P1, PORT_INT_LEVEL3);

	PORT_controlInt(PORT_NO_P0, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
	PORT_controlInt(PORT_NO_P1, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_ENABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
}

/*
 * set registers for outputs.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void setPortOutput(void)
{
	// set output settings
	PORT_controlOutput(PORT_NO_P1, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);

	PORT_controlInput(PORT_NO_P1, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);

	PORT_setOutputData(PORT_NO_P1, PORT_MAIN_PORT_OUT_LOW);

	flgP1xOut = PORT_MAIN_PORT_OUT_LOW;
}

/*
 * clear registers for interrupt inputs.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void clearPortInput(void)
{
	// clear input settings
	PORT_controlInt(PORT_NO_P0, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
	PORT_controlInt(PORT_NO_P1, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);

	PORT_initInt(PORT_NO_P0, PORT_INT_LEVEL0);
	PORT_initInt(PORT_NO_P1, PORT_INT_LEVEL0);

	PORT_setIntEdge(PORT_NO_P0, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
	PORT_setIntEdge(PORT_NO_P1, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);

	PORT_controlInput(PORT_NO_P0, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);
	PORT_controlInput(PORT_NO_P1, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);

	PORT_controlOutput(PORT_NO_P0, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
	PORT_controlOutput(PORT_NO_P1, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);

	PORT_controlSchmittTrigger(PORT_NO_P0, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);
	PORT_controlSchmittTrigger(PORT_NO_P1, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);

	PORT_controlPullup(PORT_NO_P0, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);
	PORT_controlPullup(PORT_NO_P1, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);

	PORT_setChatteringFilter(PORT_CHATNO_P030, PORT_CHATTIME_NONE);
	PORT_setChatteringFilter(PORT_CHATNO_P174, PORT_CHATTIME_NONE);
}

/*
 * clear registers for outputs.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void clearPortOutput(void)
{
	// clear output settings
	PORT_setOutputData(PORT_NO_P1, PORT_MAIN_PORT_OUT_LOW);

	PORT_controlOutput(PORT_NO_P1, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);

	PORT_controlInput(PORT_NO_P1, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);

	flgP1xOut = PORT_MAIN_PORT_OUT_LOW;
}

/*
 * PORT P0x interrupt handler
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void portIntP0xHandler(void)
{
	unsigned char	flgIntr;	// interrupt status

	// get interrupt status
	PORT_checkIntFlag(PORT_NO_P0, &flgIntr);

	// clear interrupt status
	PORT_resetIntFlag(PORT_NO_P0, flgIntr);

	if(callBackFunction[PORT_NO_P0] != 0) {
		callBackFunction[PORT_NO_P0]();			// call back
	} else {
		if((flgIntr & PORT_BIT_X2) == PORT_BIT_X2) {
			printf("*** P02 Interrupt ***\n");

			flgP1xOut ^= PORT_BIT_X0;			// toggle
			PORT_setOutputData(PORT_NO_P1, flgP1xOut);
		} else if((flgIntr & PORT_BIT_X3) == PORT_BIT_X3) {
			endFlag = 1;
		} else {
			;
		}
	}
}

/*
 * PORT P1x interrupt handler
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void portIntP1xHandler(void)
{
	unsigned char	flgIntr;	// interrupt status

	// get interrupt status
	PORT_checkIntFlag(PORT_NO_P1, &flgIntr);

	// clear interrupt status
	PORT_resetIntFlag(PORT_NO_P1, flgIntr);

	if(callBackFunction[PORT_NO_P1] != 0) {
		callBackFunction[PORT_NO_P1]();			// call back
	} else {
		if((flgIntr & PORT_BIT_X5) == PORT_BIT_X5) {
			printf("*** P15 Interrupt ***\n");

			flgP1xOut ^= PORT_BIT_X1;			// toggle
			PORT_setOutputData(PORT_NO_P1, flgP1xOut);
		}
	}
}

/*
 * set interrupt call back function.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void portSetCallBackFunc(unsigned char chNo, void(*name)(void))
{
	if(chNo < PORT_NO_MAX) {
		callBackFunction[chNo] = name;
	}
}

/*
 * clear interrupt call back function.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void portClearCallBackFunc(unsigned char chNo)
{
	if(chNo < PORT_NO_MAX) {
		callBackFunction[chNo] = 0;
	}
}


#endif	// end of PE_PORT
