/*************************************************************
 * t8f_main.c
 *
 * 8-bit timer main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2009. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <s1c176xx.h>

#ifdef	PE_T8F
#include <t8f_api.h>

#define	T8F_TARGET_CH			T8F_CH0									// test target channel
#define	T8F_MAIN_LOOP_CT_MAX	10						// loop counter max
#define T8F_COMPARE_DATA		0x80		//compare data


static unsigned char	t8FbufCounter[T8F_MAIN_LOOP_CT_MAX] = {0};	// counter record buffer
static volatile unsigned char	t8FloopCt;									// loop counter

/* prototype */
void t8fMain(void);
static void startT8F(unsigned char chNo);
static void stopT8F(unsigned char chNo);
void t8fIntHandler(void)__attribute__ ((interrupt_handler));


/*
 * T8F timer sample program
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void t8fMain(void)
{
	printf("<<< T8F timer demonstration start >>>\n");

	//start T8F timer
	startT8F(T8F_TARGET_CH);

	t8FloopCt = 0;
	while(t8FloopCt < T8F_MAIN_LOOP_CT_MAX) {
		asm( "halt" );
		asm( "nop" );
		t8FloopCt++;
	}

	// stop T8F timer
	stopT8F(T8F_TARGET_CH);

	// outoput result
	t8FloopCt = 0;
	while(t8FloopCt < T8F_MAIN_LOOP_CT_MAX) {
		t8FloopCt++;
		printf("T8F interrupt %d time, count data at this time : %d\n", t8FloopCt, t8FbufCounter[t8FloopCt - 1U]);
	}

	printf("<<< T8F timer demonstration finish >>>\n");
}

/*
 * start T8F timer for 1 sec interval.
 * param	T8F channel number.
 * return	void
 * history	:	2009/12/25
 */
static void startT8F(unsigned char chNo)
{
	T8F_INIT_PARAM t8fInitParam = {										// initialize parameter
					T8F_TIMMODE_PATTERN0,
					T8F_TIMMODE_REPEAT,
					T8F_CNTCLK_16384,
					T8F_COMPARE_DATA};

	T8F_init(chNo, &t8fInitParam);
	T8F_initInt(T8F_INT_LEVEL3);
	T8F_controlInt(chNo, T8F_INT_ENABLE);
	T8F_setTimerRun(chNo, T8F_TIMER_RUN);
}


/*
 * stop T8F timer.
 * param	T8F channel number.
 * return	void
 * history	:	2009/12/25
 */
static void stopT8F(unsigned char chNo)
{
	T8F_setTimerRun(chNo, T8F_TIMER_STOP);
	T8F_controlInt(chNo, T8F_INT_DISABLE);
	T8F_initInt(T8F_INT_LEVEL0);
}

/*
 * T8F interrupt handler.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void t8fIntHandler(void)
{
	// reset interrupt flag
	T8F_resetIntFlag(T8F_TARGET_CH);

	// get counter value
	if(t8FloopCt < T8F_MAIN_LOOP_CT_MAX) {
		T8F_getCounterData(T8F_TARGET_CH, &t8FbufCounter[t8FloopCt]);
	}
}
#endif	// end of PE_T8F
