/*************************************************************
 * wdt_main.c
 *
 * watchdog timer main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2009. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <s1c176xx.h>

#ifdef	PE_WDT
#include <wdt_api.h>
#include <t16_api.h>


#define	WDT_T16_LOOP_CT_MAX	10						// loop counter max

static volatile unsigned char	wstT16LoopCt;				// loop counter

void wdtMain(void);
static void startT16(unsigned char chNo);
static void startWDT(void);
static void stopWDT(void);
static void stopT16(unsigned char chNo);
void wdtT16IntHandler(void);
extern void t16SetCallBackFunc(void(*name)(void));
extern void t16ClearCallBackFunc(void);


/*
 * WDT timer sample program
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void wdtMain(void)
{
	printf("<<< Watchdog timer demonstration start >>>\n");

	// set a call back function to T16 interrupt handler
	t16SetCallBackFunc(&wdtT16IntHandler);

	// start T16 timer
	startT16(T16_CH0);
	
	// start WDT
	startWDT();

	wstT16LoopCt = 0;
	while(wstT16LoopCt < WDT_T16_LOOP_CT_MAX) {
		asm("halt");
		asm("nop");
		wstT16LoopCt++;
	}

	// stop T16 timer
	stopT16(T16_CH0);
	
	printf("*** stop T16 timer ***\n");

	// unregister a call back function from T16 timer handler
	t16ClearCallBackFunc();

	// wait watchdog NMI interrupt
	while(1) {
		asm("halt");
		asm("nop");
		
		// check NMI interrupt
		if(WDT_checkNMI() == WDT_OCCURRED) {
			printf("*** NMI occurred ***\n");
			break;
		}
		WDT_resetTimer();
	}
	// stop WDT
	stopWDT();

	printf("<<< Watchdog timer demonstration finish >>>\n");
}

/*
 * start T16 timer for 1 sec interval.
 * param	T16 channel number.
 * return	void
 * history	:	2009/12/25
 */
static void startT16(unsigned char chNo)
{
	T16_TIM_MODE	mode;	// timer mode setting

	mode.ckactv	= T16_TIMMODE_ACTVL;
	mode.cksl	= T16_TIMMODE_INTERNAL;
	mode.trmd	= T16_TIMMODE_REPEAT;
	T16_init(chNo, T16_CNTCLK_16384, &mode, OSC3_CLK/16384);
	
	T16_initInt(chNo, T16_INT_LEVEL3);
	T16_controlInt(chNo, T16_INT_ENABLE);
	T16_setTimerRun(chNo, T16_TIMER_RUN);
}

/*
 * start WDT timer.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void startWDT(void)
{
	WDT_setTimerMode(WDT_TIMMODE_NMI);
	
	WDT_resetTimer();
	WDT_setTimerRun(WDT_TIMER_RUN);
}


/*
 * stop WDT timer.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void stopWDT(void)
{
	WDT_setTimerRun(WDT_TIMER_STOP);
	WDT_resetTimer();
}


/*
 * stop T16 timer.
 * param	T16 channel number.
 * return	void
 * history	:	2009/12/25
 */
static void stopT16(unsigned char chNo)
{
	T16_setTimerRun(chNo, T16_TIMER_STOP);
	T16_controlInt(chNo, T16_INT_DISABLE);
	T16_initInt(chNo, T16_INT_LEVEL0);
}


/*
 * T16 interrupt handler.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void wdtT16IntHandler(void)
{
	// reset interrupt flag
	T16_resetIntFlag(T16_CH0);

	if(wstT16LoopCt < WDT_T16_LOOP_CT_MAX) {
		WDT_resetTimer();
		printf("*** T16 timer : reset watchdog timer ***\n");
	}
}

#endif	// end of PE_WDT
