/******************************************************************
 * mux_api.h
 *
 * MUX driver
 *
 * Copyright(C) SEIKO EPSON CORPORATION 2010. All rights Reserved.
 *****************************************************************/

#ifndef MUX_API_H_
#define MUX_API_H_

#include <mux.h>

/******************************************
 * definition of "define"
 ******************************************/

// MUX driver return code.
#define	MUX_SUCCESS					 0								// success
#define	MUX_INVALID_PARAMETER		-1								// invalid parameter
#define	MUX_FAILURE					-2								// failure

// MUX on / off select.
#define	MUX_OFF						0								// port select
#define	MUX_ON						1								// function select

// set ADC port.
#define	MUX_ADTRG_OFF				0x00							// select external trigger off
#define	MUX_ADTRG_ON				0x01							//						   on

// set SPI port.
enum {
	MUX_SPI_SPICLK = 0,												// 0x00 : SPICLK
	MUX_SPI_SDO,													// 0x01 : SDO
	MUX_SPI_SDI,													// 0x02 : SDI
	MUX_SPI_SPISS,													// 0x03 : SPISS

	MUX_SPI_PORTMAX
};

// set UART port.
enum {
	MUX_UART_SOUT = 0,												// 0x00 : SOUT
	MUX_UART_SIN,													// 0x01 : SIN
	MUX_UART_SCLK,													// 0x02 : SCLK

	MUX_UART_PORTMAX
};

#if	defined(S1C17624) || defined(S1C17622)
enum {
	MUX_UART_CH1_0 = 0,												// 0x00 : port select number 0
	MUX_UART_CH1_1,													// 0x01 : port select number 1
	MUX_UART_CH0,													// 0x02 : not select

	MUX_UART_CH_MAX
};
#endif	// end of S1C17624/S1C17622

#define	MUX_UART_CLK_INTERNAL		0x00							// select input clock : internal
#define	MUX_UART_CLK_EXTERNAL		0x01							//					  : external

// set RFC port.
enum {
	MUX_RFC_RFIN = 0,												// 0x00 : RFIN
	MUX_RFC_REF,													// 0x01 : REF
	MUX_RFC_SENA,													// 0x02 : SENA
	MUX_RFC_SENB,													// 0x03 : SENB

	MUX_RFC_PORTMAX
};

enum {
	MUX_RFCLK_P36 = 0,												// 0x00 : select P36 for RFCLK
	MUX_RFCLK_P46,													// 0x01 : select P46 for RFCLK
	MUX_RFCLK_P36_P46,												// 0x02 : select P36 and P46 for RFCLK
	MUX_RFCLK_POFF,													// 0x03 : not use RFCLK

	MUX_RFCLK_MAX
};

#define	MUX_RFIN_OFF				0x00							// select external clock off
#define	MUX_RFIN_ON					0x01							//						 on
#define	MUX_REF_OFF					0x00							// select reference off
#define	MUX_REF_ON					0x01							//					on
#define	MUX_SENA_OFF				0x00							// select sensor A off
#define	MUX_SENA_ON					0x01							//				   on
#define	MUX_SENB_OFF				0x00							// select sensor B off
#define	MUX_SENB_ON					0x01							//				   on
#define	MUX_RFCLK_OFF				0x00							// select RFCLK output off
#define	MUX_RFCLK_ON				0x01							//					   on

// set I2C master port.
enum {
	MUX_I2CM_SCL = 0,												// 0x00 : SCL
	MUX_I2CM_SDA,													// 0x01 : SDA

	MUX_I2CM_PORTMAX
};

#define	MUX_I2CM_0					0x00							// select number 0
#define	MUX_I2CM_1					0x01							//				 1

// set I2C slave port.
enum {
	MUX_I2CS_SCL = 0,												// 0x00 : SCL
	MUX_I2CS_SDA,													// 0x01 : SDA
	MUX_I2CS_xBFR,													// 0x02 : #BFR

	MUX_I2CS_PORTMAX
};

#if	defined(S1C17624) || defined(S1C17622)
#define	MUX_I2CS_0					0x00							// select number 0
#define	MUX_I2CS_1					0x01							//				 1
#endif	// end of S1C17624/S1C17622

// set OSC port.
#define	MUX_FOUT1_OFF				0x00							// select FOUT1 off
#define	MUX_FOUT1_ON				0x01							//				on
#define	MUX_FOUTH_OFF				0x00							// select FOUTH off
#define	MUX_FOUTH_ON				0x01							//				on

// set PWM timer port.
enum {
	MUX_T16E_T3 = 0,												// 0x00 : TOUT3
	MUX_T16E_TN3,													// 0x01 : TOUTN3

	MUX_T16E_PORTMAX
};

// set LCD port.
enum {
	MUX_LFRO_P37 = 0,												// 0x00 : select P37 for LFRO
	MUX_LFRO_P54,													// 0x01 : select P54 for LFRO
	MUX_LFRO_P37_P54,												// 0x02 : select P37 and P54 for LFRO

	MUX_LFRO_MAX
};

// set T8OSC1 timer port.
enum {
	MUX_TOUT4_P37 = 0,												// 0x00 : select P37 for TOUT4
	MUX_TOUT4_P47,													// 0x01 : select P47 for TOUT4
	MUX_TOUT4_P37_P47,												// 0x02 : select P37 and P47 for TOUT4

	MUX_TOUT4_MAX
};

// set PWM timer(T16A2) port.
enum {
	MUX_T16A2_TOUTA = 0,												// 0x00 : TOUTA
	MUX_T16A2_TOUTB,													// 0x01 : TOUTB
	MUX_T16A2_EXCLOUT,													// 0x02 : EXCLOUT
	MUX_T16A2_EXCLIN,													// 0x03 : EXCLIN
	MUX_T16A2_EXCL,														// 0x04 : EXCL

	MUX_T16A2_PORTMAX
};

#define	MUX_EXCL_OFF				0x00							// select external clock off
#define	MUX_EXCL_ON					0x01							//						 on
#define	MUX_TOUTA_OFF				0x00							// select TOUTA off
#define	MUX_TOUTA_ON				0x01							//				on
#define	MUX_TOUTB_OFF				0x00							// select TOUTB off
#define	MUX_TOUTB_ON				0x01							//

#ifdef	S1C17624
enum {
	MUX_EXCLXS_OFF = 0,													// 0x00 : not use external clock
	MUX_EXCL5S_CH0_P36,													// 0x01 : use external clock by P36
	MUX_EXCL5S_CH0_P47,													// 0x02 : use external clock by P47
	MUX_EXCL6S_CH1_P37,													// 0x03 : use external clock by P37
	MUX_EXCL6S_CH1_P50,													// 0x04 : use external clock by P50

	MUX_EXCLXS_MAX
};

enum {
	MUX_TOUTAXP_OFF = 0,												// 0x00 : not use TOUTA
	MUX_TOUTA5P_CH0_P31,												// 0x01 : use TOUTA5 by P31
	MUX_TOUTA5P_CH0_P51,												// 0x02 : use TOUTA5 by P51
	MUX_TOUTA5P_CH0_P31_P51,											// 0x03 : use TOUTA5 by P31 and P51
	MUX_TOUTA6P_CH1_P33,												// 0x04 : use TOUTA6 by P33
	MUX_TOUTA6P_CH1_P55,												// 0x05 : use TOUTA6 by P55
	MUX_TOUTA6P_CH1_P33_P55,											// 0x06 : use TOUTA6 by P33 and P55

	MUX_TOUTAXP_MAX
};

enum {
	MUX_TOUTBXP_OFF = 0,												// 0x00 : not use TOUTB
	MUX_TOUTB5P_CH0_P32,												// 0x01 : use TOUTB5 by P32
	MUX_TOUTB5P_CH0_P52,												// 0x02 : use TOUTB5 by P52
	MUX_TOUTB5P_CH0_P32_P52,											// 0x03 : use TOUTB5 by P32 and P52
	MUX_TOUTB6P_CH1_P34,												// 0x04 : use TOUTB6 by P34
	MUX_TOUTB6P_CH1_P56,												// 0x05 : use TOUTB6 by P56
	MUX_TOUTB6P_CH1_P34_P56,											// 0x06 : use TOUTB6 by P34 and P56

	MUX_TOUTBXP_MAX
};
#endif	// end of S1C17624

/******************************************
 * definition of "struct"
 ******************************************/

// select RFC use port.
struct tag_MUX_USE_RFCPORT;
typedef struct tag_MUX_USE_RFCPORT {
	unsigned char	useRfin;										// select external clock
	unsigned char	useRef;											// select reference
	unsigned char	useSenA;										// select sensor A
	unsigned char	useSenB;										// select sensor B
	unsigned char	useRfclk;										// select RFCLK output
#if defined(S1C17624) || defined(S1C17622)
	unsigned char	useRFCLKS;										// select RFCLK port
#endif	// end of S1C17624/S1C17622
} MUX_USE_RFCPORT;

struct tag_MUX_USE_UARTPORT;
typedef struct tag_MUX_USE_UARTPORT {
	unsigned char	sw;												// select port on/off
#if	defined(S1C17624) || defined(S1C17622)
	unsigned char	selectNo;											// select SIN/SOUT/SCLK
#endif	// end of S1C17624/S1C17622
} MUX_USE_UARTPORT;

struct tag_MUX_USE_I2CSPORT;
typedef struct tag_MUX_USE_I2CSPORT {
	unsigned char	sw;												// select port on/off
#if	defined(S1C17624) || defined(S1C17622)
	unsigned char	selectNo;											// select SCL/SDA/#BFR
#endif	// end of S1C17624/S1C17622
} MUX_USE_I2CSPORT;

struct tag_MUX_USE_LCDPORT;
typedef struct tag_MUX_USE_LCDPORT {
	unsigned char	sw;												// select port on/off
#if	defined(S1C17624) || defined(S1C17622)
	unsigned char	useLFRO;										// select LFRO port
#endif	// end of S1C17624/S1C17622
} MUX_USE_LCDPORT;

struct tag_MUX_USE_T8OSC1PORT;
typedef struct tag_MUX_USE_T8OSC1PORT {
	unsigned char	sw;												// select port on/off
#if	defined(S1C17624) || defined(S1C17622)
	unsigned char	useTOUT4;										// select TOUT4 port
#endif	// end of S1C17624/S1C17622
} MUX_USE_T8OSC1PORT;

// select T16A2 use port.
struct tag_MUX_USE_T16A2PORT;
typedef struct tag_MUX_USE_T16A2PORT {
	unsigned char	useEXCL;										// set external clock on/off
	unsigned char	useToutA;										// set ToutA on/off
	unsigned char	useToutB;										// set ToutB on/off
#ifdef S1C17624
	unsigned char	useEXCLS;										// select external clock port
	unsigned char	useToutAPort;									// select ToutA port
	unsigned char	useToutBPort;									// select ToutB port
#endif // end of S1C17624
} MUX_USE_T16A2PORT;


/******************************************
 * Declarations of function prototype
 ******************************************/
#ifdef	PE_PORT
extern void MUX_init(void);
#endif	// end of PE_PORT
#ifdef	PE_REMC
extern short MUX_setREMCport(unsigned char sw);
#endif	// end of PE_REMC
#ifdef	PE_ADC
extern short MUX_setADCport(unsigned char use, unsigned short startCh, unsigned short endCh, unsigned char sw);
#endif	// end of PE_ADC
#ifdef	PE_SPI
extern short MUX_setSPIport(unsigned char chNo, unsigned char sw);
#endif	// end of PE_SPI
#ifdef	PE_UART
extern short MUX_setUARTport(unsigned char chNo, unsigned char inputClk, MUX_USE_UARTPORT *use);
#endif	// end of PE_UART
#ifdef	PE_RFC
extern short MUX_setRFCport(unsigned char chNo, MUX_USE_RFCPORT *use, unsigned char sw);
#endif	// end of PE_RFC
#ifdef	PE_I2CM
extern short MUX_setI2CMport(unsigned char selectNo, unsigned char sw);
#endif	// end of PE_I2CM
#ifdef	PE_I2CS
extern short MUX_setI2CSport(MUX_USE_I2CSPORT *use);
#endif	// end of PE_I2CS
#ifdef	PE_CLG_OSC
extern short MUX_setOSCport(unsigned char useFout1, unsigned char useFouth, unsigned char sw);
#endif	// end of PE_CLG_OSC
#ifdef	PE_T16E
extern short MUX_setT16Eport(unsigned char chNo, unsigned char sw);
#endif	// end of PE_T16E
#ifdef	PE_LCD
extern short MUX_setLCDport(MUX_USE_LCDPORT *use);
#endif	// end of PE_LCD
#ifdef	PE_T8OSC1
extern short MUX_setT8OSC1port(MUX_USE_T8OSC1PORT *use);
#endif	// end of PE_T8OSC1
extern short MUX_setDBGport(unsigned char sw);
#ifdef	PE_T16
extern short MUX_setT16port(unsigned char chNo, unsigned char sw);
#endif	// end of PE_T16
#ifdef PE_T16A2
extern short MUX_setT16A2port(unsigned char chNo, MUX_USE_T16A2PORT *use, unsigned char sw);
#endif // end of PE_T16A2


#endif	// end of MUX_API_H_
