/******************************************************************
 * osc_api.h
 *
 * OSC driver
 *
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef OSC_API_H_
#define OSC_API_H_

#include <osc.h>

/******************************************
 * definition of "define"
 ******************************************/

// OSC driver return code.
#define CLG_OSC_SUCCESS				 0								// success
#define CLG_OSC_INVALID_PARAMETER		-1								// invalid parameter
#define CLG_OSC_FAILURE				-2								// failure

// OSC clock control.
#define CLG_OSC_SELHSCLK_IOSC			SRC_IOSC						// select High-speed clock : IOSC
#define CLG_OSC_SELHSCLK_OSC3			SRC_OSC3						//						   : OSC3
#define CLG_OSC_SELCLKSRC_HSCLK		SRC_HSCLK						// select system clock source : HSCLK
#define CLG_OSC_SELCLKSRC_OSC1			SRC_OSC1						//							  : OSC1

enum {
	CLG_OSC_SELIOSC_64 = 0,												// 0x00 : select IOSC wait cycle : 64 cycle
	CLG_OSC_SELIOSC_32,													// 0x01 :						 : 32 cycle
	CLG_OSC_SELIOSC_16,													// 0x02 :						 : 16 cycle
	CLG_OSC_SELIOSC_8,													// 0x03 :						 :  8 cycle

	CLG_OSC_SELIOSC_MAX
};

enum {
	CLG_OSC_SELOSC3_1024  = 0,											// 0x00 : select OSC3 wait cycle : 1024 cycle
	CLG_OSC_SELOSC3_512,												// 0x01 :						 :  512 cycle
	CLG_OSC_SELOSC3_256,												// 0x02 :						 :  256 cycle
	CLG_OSC_SELOSC3_128,												// 0x03 :						 :  128 cycle

	CLG_OSC_SELOSC3_MAX
};

// OSC oscillation control.
#define CLG_OSC_IOSC_DISABLE			(IOSCEN*OSC_DISABLE)			// IOSC disable
#define CLG_OSC_IOSC_ENABLE				(IOSCEN*OSC_ENABLE)				//		enable
#define CLG_OSC_OSC1_DISABLE			(OSC1EN*OSC_DISABLE)			// OSC1 disable
#define CLG_OSC_OSC1_ENABLE				(OSC1EN*OSC_ENABLE)				//		enable
#define CLG_OSC_OSC3_DISABLE			(OSC3EN*OSC_DISABLE)			// OSC3 disable
#define CLG_OSC_OSC3_ENABLE				(OSC3EN*OSC_ENABLE)				//		enable

// OSC noise filter control.
#define CLG_OSC_NOISE_RESET_DISABLE		(RSTFE*OSC_DISABLE)				// reset noise filter disable
#define CLG_OSC_NOISE_RESET_ENABLE		(RSTFE*OSC_ENABLE)				//					  enable
#define CLG_OSC_NOISE_NMI_DISABLE		(NMIFE*OSC_DISABLE)				// NMI noise filter disable
#define CLG_OSC_NOISE_NMI_ENABLE		(NMIFE*OSC_ENABLE)				//					enable

// LCD clock control.
#define CLG_OSC_LCDCLK_HSCLK			LCKSRC_HSCLK					// select LCD clock source : HSCLK
#define CLG_OSC_LCDCLK_OSC1				LCKSRC_OSC1						//						   : OSC1

// LCD clock source the case of HSCLK
enum {
	CLG_OSC_LCDRATIO_32 = 0,											// 0x00 : select LCD clock division ratio : HSCLK1/32
	CLG_OSC_LCDRATIO_64,												// 0x01 :								  : HSCLK1/64
	CLG_OSC_LCDRATIO_128,												// 0x02 :								  : HSCLK1/128
	CLG_OSC_LCDRATIO_256,												// 0x03 :								  : HSCLK1/256
	CLG_OSC_LCDRATIO_512,												// 0x04 :								  : HSCLK1/512

	CLG_OSC_LCDRATIO_MAX
};

#define CLG_OSC_LCDCLK_DISABLE			OSC_DISABLE						// LCD clock disable
#define CLG_OSC_LCDCLK_ENABLE			OSC_ENABLE						//			 enable

// FOUT clock control.
enum {
	CLG_OSC_FOUTCLK_1 = 0,												// 0x00 : select FOUTH clock division ratio : HSCLK1/1
	CLG_OSC_FOUTCLK_2,													// 0x01 :									: HSCLK1/2
	CLG_OSC_FOUTCLK_4,													// 0x02 :									: HSCLK1/4

	CLG_OSC_FOUTCLK_MAX
};

#define CLG_OSC_FOUTH_DISABLE			(FOUTHE*OSC_DISABLE)			// FOUTH output disable
#define CLG_OSC_FOUTH_ENABLE			(FOUTHE*OSC_ENABLE)				//				enable
#define CLG_OSC_FOUT1_DISABLE			(FOUT1E*OSC_DISABLE)			// FOUT1 output disable
#define CLG_OSC_FOUT1_ENABLE			(FOUT1E*OSC_ENABLE)				//				enable

// T8OSC1 clock control.
enum {
	CLG_OSC_T8OSC1CLK_1 = 0,											// 0x00 : select T8SC1 clock divisio ratio : HSCLK1/1
	CLG_OSC_T8OSC1CLK_2,												// 0x01 :								   : HSCLK1/2
	CLG_OSC_T8OSC1CLK_4,												// 0x02 :								   : HSCLK1/4
	CLG_OSC_T8OSC1CLK_8,												// 0x03 :								   : HSCLK1/8
	CLG_OSC_T8OSC1CLK_16,												// 0x04 :								   : HSCLK1/16
	CLG_OSC_T8OSC1CLK_32,												// 0x05 :								   : HSCLK1/32

	CLG_OSC_T8OSC1CLK_MAX
};

#define CLG_OSC_T8OSC1_DISABLE			(T8O1CE*OSC_DISABLE)			// T8OSC1 clock output disable
#define CLG_OSC_T8OSC1_ENABLE			(T8O1CE*OSC_ENABLE)				//					   enable

// SVD clock control.
#define CLG_OSC_SVDCLK_HSCLK			SVDSRC_HSCLK					// select SVD clock source : HSCLK1/512
#define CLG_OSC_SVDCLK_OSC1				SVDSRC_OSC1						//						   : OSC1

#define CLG_OSC_SVD_DISABLE				OSC_DISABLE						// SVD clock disable
#define CLG_OSC_SVD_ENABLE				OSC_ENABLE						// 			 enable

// RFC clock control.
#define CLG_OSC_RFCCLK_HSCLK			RFTCKSRC_HSCLK					// select RFC TC clock source : HSCLK
#define CLG_OSC_RFCCLK_OSC1				RFTCKSRC_OSC1					//							  : OSC1

// RFC TC clock source the case of HSCLK
enum {
	CLG_OSC_RFCRATIO_1 = 0,												// 0x00 : select RFC TC clock division ratio : HSCLK1/1
	CLG_OSC_RFCRATIO_2,													// 0x01 :									 : HSCLK1/2
	CLG_OSC_RFCRATIO_4,													// 0x02 :									 : HSCLK1/4
	CLG_OSC_RFCRATIO_8,													// 0x03 :									 : HSCLK1/8

	CLG_OSC_RFCRATIO_MAX
};

#define CLG_OSC_RFCCLK_DISABLE			OSC_DISABLE						// RFC TC clock disable
#define CLG_OSC_RFCCLK_ENABLE			OSC_ENABLE						//				enable

#if defined(S1C17624) || defined(S1C17604)
// PWM timer(T16A2) input clock
enum {
	CLG_OSC_T16A2_CH0 = 0,												// 0x00 : channel 0
	CLG_OSC_T16A2_CH1,													// 0x01 : channel 1

	CLG_OSC_T16A2_CH_MAX
};

enum {
	CLG_OSC_T16A2RATIO_1 = 0,											// 0x00 : select clock division ratio: clock source1/1
	CLG_OSC_T16A2RATIO_2,												// 0x01 :							 : clock source1/2
	CLG_OSC_T16A2RATIO_4,												// 0x02 :							 : clock source1/4
	CLG_OSC_T16A2RATIO_8,												// 0x03 :							 : clock source1/8
	CLG_OSC_T16A2RATIO_16,												// 0x04 :							 : clock source1/16
	CLG_OSC_T16A2RATIO_32,												// 0x05 :							 : clock source1/32
	CLG_OSC_T16A2RATIO_64,												// 0x06 :							 : clock source1/64
	CLG_OSC_T16A2RATIO_128,												// 0x07 :							 : clock source1/128
	CLG_OSC_T16A2RATIO_256,												// 0x08 :							 : clock source1/256
	CLG_OSC_T16A2RATIO_512,												// 0x09 :							 : clock source1/512
	CLG_OSC_T16A2RATIO_1024,											// 0x0A :							 : clock source1/1024
	CLG_OSC_T16A2RATIO_2048,											// 0x0B :							 : clock source1/2048
	CLG_OSC_T16A2RATIO_4096,											// 0x0C :							 : clock source1/4096
	CLG_OSC_T16A2RATIO_8192,											// 0x0D :							 : clock source1/8192
	CLG_OSC_T16A2RATIO_16384,											// 0x0E :							 : clock source1/16384

	CLG_OSC_T16A2RATIO_MAX
};

enum {
	CLG_OSC_T16A2CLK_IOSC = 0,											// 0x00 : select clock source : IOSC
	CLG_OSC_T16A2CLK_OSC1,												// 0x01 :					  : OSC1
	CLG_OSC_T16A2CLK_OSC3,												// 0x02 :					  : OSC3
	CLG_OSC_T16A2CLK_EXTERNAL,											// 0x03 :					  : external clock

	CLG_OSC_T16A2CLK_MAX
};

#define	CLG_OSC_T16A2MD_NORMAL		T16A_NORMAL					// select multi-comparator/capture mode : normal
#define	CLG_OSC_T16A2MD_MULTI		T16A_MULTI					//										: multi

#define	CLG_OSC_T16A2CLK_DISABLE		T16A_CLKDIS					// select count clock : disable
#define	CLG_OSC_T16A2CLK_ENABLE			T16A_CLKENA					//					  : enable

// RTC clock control
#define	CLG_OSC_RTCCLK_DISABLE			RTC_CLKDIS					// input clock : disable
#define	CLG_OSC_RTCCLK_ENABLE			RTC_CLKENA					//				 enable


/******************************************
 * definition of "struct"
 ******************************************/
// PWM timer(T16A2) input clock parameter.
struct tag_CLG_OSC_SET_T16A2;
typedef struct tag_CLG_OSC_SET_T16A2 {
	unsigned short	clkdiv;											// select clock division ratio
	unsigned short	clksrc;											// select clock source
	unsigned short	multimd;										// select multi-comparator/capture mode
} CLG_OSC_SET_T16A2;
#endif // end of S1C17624/S1C17604


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short CLG_OSC_setClockSource(unsigned char selectHSCLK, unsigned char selectCLKSRC);
extern short CLG_OSC_setWaitCycle(unsigned char selectIOSC, unsigned char selectOSC3);
extern short CLG_OSC_controlOscillation(unsigned char selectBit);
extern short CLG_OSC_setNoiseFilter(unsigned char selectBit);
extern short CLG_OSC_setLCDClock(unsigned char selectOsc, unsigned char selectRatio);
extern short CLG_OSC_controlLCDClock(unsigned char selectBit);
extern short CLG_OSC_setFOUTHDivision(unsigned char selectBit);
extern short CLG_OSC_controlFOUT(unsigned char selectBit);
extern short CLG_OSC_setT8OSC1Division(unsigned char selectBit);
extern short CLG_OSC_controlT8OSC1(unsigned char selectBit);
extern short CLG_OSC_setSVDClock(unsigned char selectBit);
extern short CLG_OSC_controlSVD(unsigned char selectBit);
extern short CLG_OSC_setRFCClock(unsigned char selectOsc, unsigned char selectRatio);
extern short CLG_OSC_controlRFC(unsigned char selectBit);
#if	defined(S1C17624) || defined(S1C17604)
extern short CLG_OSC_setT16A2Clock(unsigned char chNo, CLG_OSC_SET_T16A2 *select);
extern short CLG_OSC_controlT16A2(unsigned char chNo, unsigned char selectBit);
extern short CLG_OSC_controlRTC(unsigned char selectBit);
#endif	// end of S1C17624/S1C17604
#endif	// end of OSC_API_H_
