/******************************************************************
 * rtc_api.h
 *
 * real time clock driver
 *
 * Copyright(C) SEIKO EPSON CORPORATION 2010. All rights Reserved.
 *****************************************************************/

#ifndef RTC_API_H_
#define RTC_API_H_

#include <rtc.h>

/******************************************
 * definition of "define"
 ******************************************/

// real time clock driver return code.
#define	RTC_SUCCESS					 0								// success
#define	RTC_INVALID_PARAMETER		-1								// invalid parameter
#define	RTC_FAILURE					-2								// failure

//  interrupt level.
enum {
	RTC_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	RTC_INT_LEVEL1,													// 0x01:interrupt level 1
	RTC_INT_LEVEL2,													// 0x02:interrupt level 2
	RTC_INT_LEVEL3,													// 0x03:interrupt level 3
	RTC_INT_LEVEL4,													// 0x04:interrupt level 4
	RTC_INT_LEVEL5,													// 0x05:interrupt level 5
	RTC_INT_LEVEL6,													// 0x06:interrupt level 6
	RTC_INT_LEVEL7,													// 0x07:interrupt level 7

	RTC_INT_LEVELMAX
};


// RTC interrupt flag.
#define	RTC_INT_NOTOCCURRED			RTC_NOTOCCURRED					// not occurred
#define	RTC_INT_OCCURRED			RTC_OCCURRED					// occurred

// RTC interrupt
#define	RTC_INT_DISABLE				RTC_DISABLE						// interrupt disable
#define	RTC_INT_ENABLE				RTC_ENABLE						// 			 enable

// RTC interrupt mode
#define	RTC_INT_MODE_EDGE			RTC_EDGE						// edge trigger
#define	RTC_INT_MODE_LEVEL			RTC_LEVEL						// level sense

// RTC interrupt cycle
enum {
	RTC_INT_CYCLE_1_64S = 0x00,										// 0x00:interrupt cycle  1/64 second
	RTC_INT_CYCLE_SECOND,											// 0x01:interrupt cycle  1 second
	RTC_INT_CYCLE_MINUTE,											// 0x02:interrupt cycle  1 minute
	RTC_INT_CYCLE_HOUR,												// 0x03:interrupt cycle  1 hour
	RTC_INT_CYCLE_1_512S,											// 0x04:interrupt cycle  1/512 second
	RTC_INT_CYCLE_1_256S,											// 0x05:interrupt cycle  1/256 second
	RTC_INT_CYCLE_1_128S,											// 0x06:interrupt cycle  1/128 second

	RTC_INT_CYCLE_MAX
};

// RTC timer run / stop control
#define RTC_TIMER_RUN					RTC_RUN							// timer run
#define RTC_TIMER_STOP					RTC_STOP						//		 stop

// RTC 24H/12H mode select.
#define	RTC_MODE_12H				RTC_12H							// mode	 12H
#define	RTC_MODE_24H				RTC_24H							//		 24H

// RTC counter hold control
#define	RTC_COUNTER_RUNNING			RTC_RUNNING						// counter running
#define	RTC_COUNTER_HOLD			RTC_HOLD						//		   hold

// RTC busy flag
#define	RTC_STATE_POSSIBLE			RTC_POSSIBLE					// R/W possible
#define	RTC_STATE_BUSY				RTC_BUSY						// busy

// RTC read buffer control
#define	RTC_READBUF_DISABLE			RTC_RBOFF						// read buffer disable
#define	RTC_READBUF_ENABLE			RTC_RBON						//			   enable

// RTC counter max
#define	RTC_COUNT_MAX				RTC_MAX							// RTC counter max value

// RTC second counter max
#define	RTC_SCOUNT_MAX				RTC_SMAX						// RTC second counter max value

// RTC minute counter max
#define	RTC_MICOUNT_MAX				RTC_MIMAX						// RTC minute counter max value

// RTC hour counter max
#define	RTC_HCOUNT_MAX				RTC_HMAX						// RTC hour counter max value

// RTC AM/PM indicator
#define	RTC_INDICATOR_AM			RTC_AM							// indicate AM or 24H mode
#define	RTC_INDICATOR_PM			RTC_PM							//			PM

// RTC day counter max
#define	RTC_DCOUNT_MIN				RTC_DMIN						// RTC day counter min value
#define	RTC_DCOUNT_MAX				RTC_DMAX						// RTC day counter max value

// RTC month counter max
#define	RTC_MOCOUNT_MIN				RTC_MOMIN						// RTC month counter min value
#define	RTC_MOCOUNT_MAX				RTC_MOMAX						// RTC month counter max value

// RTC year counter max
#define	RTC_YCOUNT_MAX				RTC_YMAX						// RTC year counter max value

// RTC week counter
enum {
	RTC_WEEK_SUNDAY = 0x00,											// 0x00:weekday  Sunday
	RTC_WEEK_MONDAY,												// 0x01:weekday  Monday
	RTC_WEEK_TUESDAY,												// 0x02:weekday  Tuesday
	RTC_WEEK_WEDNESDAY,												// 0x03:weekday  Wednesday
	RTC_WEEK_THURSDAY,												// 0x04:weekday  Thursday
	RTC_WEEK_FRIDAY,												// 0x05:weekday  Friday
	RTC_WEEK_SATURDAY,												// 0x06:weekday  Saturday
};


/******************************************
 * definition of "struct"
 ******************************************/

// PWM timer mode set parameter.
struct tag_RTC_DATE_INFO;
typedef struct tag_RTC_DATE_INFO {
	unsigned char	second;											// second counter data
	unsigned char	minute;											// minute counter data
	unsigned char	hour;											// hour counter data
	unsigned char	indicator;										// indicator (AM/PM)
	unsigned char	day;											// day counter data
	unsigned char	month;											// month counter data
	unsigned char	year;											// year counter data
	unsigned char	week;											// weekday counter data
} RTC_DATE_INFO;


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short RTC_init(unsigned char rtc24h);
extern short RTC_setTimerRun(unsigned char selectBit);
extern short RTC_setTimerMode(unsigned char rtc24H);
extern short RTC_setTime(RTC_DATE_INFO *pDate);
extern void RTC_setAdj(void);
extern void RTC_getTime(RTC_DATE_INFO *pDate);
extern void RTC_checkBusy(void);
extern short RTC_initInt(unsigned char intLevel, unsigned char intCycle, unsigned char intMode);
extern short RTC_controlInt(unsigned char selectBit);
extern void RTC_resetIntFlag(void);
extern void RTC_checkIntFlag(unsigned char *flag);

#endif /* RTC_API_H_ */
