/******************************************************************
 * svd_api.h
 * 
 * SVD driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef SVD_API_H_
#define SVD_API_H_

#include <svd.h>

/******************************************
 * definition of "define"
 ******************************************/

// SVD driver return code.
#define	SVD_SUCCESS					 0								// success
#define	SVD_INVALID_PARAMETER		-1								// invalid parameter
#define	SVD_FAILURE					-2								// failure

// SVD interrupt level.
enum {
	SVD_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	SVD_INT_LEVEL1,													// 0x01:interrupt level 1
	SVD_INT_LEVEL2,													// 0x02:interrupt level 2
	SVD_INT_LEVEL3,													// 0x03:interrupt level 3
	SVD_INT_LEVEL4,													// 0x04:interrupt level 4
	SVD_INT_LEVEL5,													// 0x05:interrupt level 5
	SVD_INT_LEVEL6,													// 0x06:interrupt level 6
	SVD_INT_LEVEL7,													// 0x07:interrupt level 7

	SVD_INT_LEVELMAX
};

// SVD compare voltage.
enum {
	SVD_COMPVOL_RSV = 0,											// 0x00 : reserved
	SVD_COMPVOL_18V,												// 0x01 : 1.8V
	SVD_COMPVOL_19V,												// 0x02 : 1.9V
	SVD_COMPVOL_20V,												// 0x03 : 2.0V
	SVD_COMPVOL_21V,												// 0x04 : 2.1V
	SVD_COMPVOL_22V,												// 0x05 : 2.2V
	SVD_COMPVOL_23V,												// 0x06 : 2.3V
	SVD_COMPVOL_24V,												// 0x07 : 2.4V
	SVD_COMPVOL_25V,												// 0x08 : 2.5V
	SVD_COMPVOL_26V,												// 0x09 : 2.6V
	SVD_COMPVOL_27V,												// 0x0a : 2.7V
	SVD_COMPVOL_28V,												// 0x0b : 2.8V
	SVD_COMPVOL_29V,												// 0x0c : 2.9V
	SVD_COMPVOL_30V,												// 0x0d : 3.0V
	SVD_COMPVOL_31V,												// 0x0e : 3.1V
	SVD_COMPVOL_32V,												// 0x0f : 3.2V
	
	SVD_COMPVOL_MAX
};

// SVD enable / disable.
#define	SVD_DETECT_DISABLE			SVD_DISABLE						// SVD disable
#define	SVD_DETECT_ENABLE			SVD_ENABLE						//	   enable

// SVD initialize parameter. 
#define	SVD_COMPVOL_NOAMAL			SVD_NORMAL						// SVD detection result : normal
#define	SVD_COMPVOL_LOW				SVD_LOW							//						: low

// SVD interrupt.
#define	SVD_INT_DISABLE				SVD_DISABLE						// SVD interrupt disable
#define	SVD_INT_ENABLE				SVD_ENABLE						//				 enable

// SVD interrupt flag.
#define	SVD_INT_RESET				SVD_RESET						// SVD interrupt reset

#define	SVD_INT_NOTOCCURRED			SVD_NOTOCCURRED					// SVD interrupt not occurred
#define	SVD_INT_OCCURRED			SVD_OCCURRED					//				 occurred


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short SVD_setCompareVoltage(unsigned char selectBit);
extern short SVD_controlDetection(unsigned char selectBit);
extern void SVD_getDetectionResult(unsigned char *result);
extern short SVD_initInt(unsigned char intLevel);
extern short SVD_controlInt(unsigned char selectBit);
extern void SVD_resetIntFlag(void);
extern void SVD_checkIntFlag(unsigned char *flag);


#endif	// end of SVD_API_H_
