/******************************************************************
 * t16_api.h
 * 
 * 16-bit timer driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef T16_API_H_
#define T16_API_H_

#include <t16.h>

/******************************************
 * definition of "define"
 ******************************************/

// 16-bit timer driver return code.
#define T16_SUCCESS					 0								// success
#define T16_INVALID_PARAMETER		-1								// invalid parameter
#define T16_FAILURE					-2								// failure

// 16-bit timer interrupt level.
enum {
	T16_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	T16_INT_LEVEL1,													// 0x01:interrupt level 1
	T16_INT_LEVEL2,													// 0x02:interrupt level 2
	T16_INT_LEVEL3,													// 0x03:interrupt level 3
	T16_INT_LEVEL4,													// 0x04:interrupt level 4
	T16_INT_LEVEL5,													// 0x05:interrupt level 5
	T16_INT_LEVEL6,													// 0x06:interrupt level 6
	T16_INT_LEVEL7,													// 0x07:interrupt level 7

	T16_INT_LEVELMAX
};

// channel number.
enum {
	T16_CH0 = 0,													// 0x00 : channel 0
	T16_CH1,														// 0x01 : channel 1
	T16_CH2,														// 0x02 : channel 2
#ifndef	T16_CHANNEL3
	T16_CH3,														// 0x03 : channel 3
#ifndef	T16_CHANNEL4
	T16_CH4,														// 0x04 : channel 4
#endif	// T16_CHANNEL4
#endif	// T16_CHANNEL3
	
	T16_CH_MAX
};

// 16-bit timer input clock.
enum {
	T16_CNTCLK_1 = 0,												// 0x00 : select timer input clock : PCLK1/1
	T16_CNTCLK_2,													// 0x01 :						   : PCLK1/2
	T16_CNTCLK_4,													// 0x02 :						   : PCLK1/4
	T16_CNTCLK_8,													// 0x03 :						   : PCLK1/8
	T16_CNTCLK_16,													// 0x04 :						   : PCLK1/16
	T16_CNTCLK_32,													// 0x05 :						   : PCLK1/32
	T16_CNTCLK_64,													// 0x06 :						   : PCLK1/64
	T16_CNTCLK_128,													// 0x07 :						   : PCLK1/128
	T16_CNTCLK_256,													// 0x08 :						   : PCLK1/256
	T16_CNTCLK_512,													// 0x09 :						   : PCLK1/512
	T16_CNTCLK_1024,												// 0x0A :						   : PCLK1/1024
	T16_CNTCLK_2048,												// 0x0B :						   : PCLK1/2048
	T16_CNTCLK_4096,												// 0x0C :						   : PCLK1/4096
	T16_CNTCLK_8192,												// 0x0D :						   : PCLK1/8192
	T16_CNTCLK_16384,												// 0x0E :						   : PCLK1/16384
	
	T16_CNTCLK_MAX
};

// 16-bit timer mode set parameter.
#define T16_TIMMODE_ACTVL			T16_LOW							// select external clock active level : Low
#define T16_TIMMODE_ACTVH			T16_HIGH						//									  : High

enum {
	T16_TIMMODE_INTERNAL = 0,										// 0x00 : select operational mode : internal clock
	T16_TIMMODE_EXTERNAL,											// 0x01 :						  : external clock
	T16_TIMMODE_PULS,												// 0x02 :						  : puls width measurement
	
	T16_TIMMODE_MAX
};

#define T16_TIMMODE_REPEAT			T16_REPEAT						// select count mode : repeat
#define T16_TIMMODE_ONESHOT			T16_ONESHOT						//					 : one shot

// 16-bit timer run / stop control.
#define T16_TIMER_STOP				T16_STOP						// timer stop
#define T16_TIMER_RUN				T16_RUN							//		 run

// 16-bit timer interrupt.
#define T16_INT_DISABLE				T16_DISABLE						// interrupt disable
#define T16_INT_ENABLE				T16_ENABLE						//			 enable


// 16-bit timer interrupt flag.
#define T16_TIMERINT_NOTOCCURRED	T16_NOTOCCURRED					// not occurred
#define T16_TIMERINT_OCCURRED		T16_OCCURRED					// occurred


/******************************************
 * definition of "struct"
 ******************************************/

// 16-bit timer mode set parameter.
struct tag_T16_TIM_MODE;
typedef struct tag_T16_TIM_MODE {
	unsigned short	ckactv;											// select external clock active level
	unsigned short	cksl;											// select operational mode
	unsigned short	trmd;											// select count mode
} T16_TIM_MODE;



/******************************************
 * Declarations of function prototype
 ******************************************/
extern short T16_init(unsigned char chNo, unsigned short selectBit, T16_TIM_MODE *mode, unsigned short data);
extern short T16_setInputClock(unsigned char chNo, unsigned short selectBit);
extern short T16_setReloadData(unsigned char chNo, unsigned short data);
extern short T16_getCounterData(unsigned char chNo, unsigned short *data);
extern short T16_setTimerMode(unsigned char chNo, T16_TIM_MODE *mode);
extern short T16_resetTimer(unsigned char chNo);
extern short T16_setTimerRun(unsigned char chNo, unsigned short selectBit);
extern short T16_initInt(unsigned char chNo, unsigned char intLevel);
extern short T16_controlInt(unsigned char chNo, unsigned short selectBit);
extern short T16_resetIntFlag(unsigned char chNo);
extern short T16_checkIntFlag(unsigned char chNo, unsigned short *flag);


#endif	// end of T16_API_H_
