/******************************************************************
 * t16a2_api.h
 *
 * PWM timer(t16a2) driver
 *
 * Copyright(C) SEIKO EPSON CORPORATION 2010. All rights Reserved.
 *****************************************************************/

#ifndef T16A2_API_H_
#define T16A2_API_H_

#include <t16a2.h>

/******************************************
 * definition of "define"
 ******************************************/

// PWM timer(T16A2) driver return code.
#define	T16A2_SUCCESS				 0								// success
#define	T16A2_INVALID_PARAMETER		-1								// invalid parameter
#define	T16A2_FAILURE				-2

// PWM timer(T16A2) interrupt level.
enum {
	T16A2_INT_LEVEL0 = 0x00,										// 0x00:interrupt level 0
	T16A2_INT_LEVEL1,												// 0x01:interrupt level 1
	T16A2_INT_LEVEL2,												// 0x02:interrupt level 2
	T16A2_INT_LEVEL3,												// 0x03:interrupt level 3
	T16A2_INT_LEVEL4,												// 0x04:interrupt level 4
	T16A2_INT_LEVEL5,												// 0x05:interrupt level 5
	T16A2_INT_LEVEL6,												// 0x06:interrupt level 6
	T16A2_INT_LEVEL7,												// 0x07:interrupt level 7

	T16A2_INT_LEVELMAX
};

// channel number.
enum {
	T16A2_CH0 = 0,													// 0x00 : channel 0
	T16A2_CH1,														// 0x01 : channel 1

	T16A2_CH_MAX
};

// PWM timer(T16A2) input clock
enum {
	T16A2_CLKSRC_IOSC = 0,											// 0x00 : select clock source : IOSC
	T16A2_CLKSRC_OSC1,												// 0x01 :					  : OSC1
	T16A2_CLKSRC_OSC3,												// 0x02 :					  : OSC3
	T16A2_CLKSRC_EXTERNAL,											// 0x03 :					  : external clock

	T16A2_CLKSRC_MAX
};

// PWM timer(T16A2) mode set parameter.
#define	T16A2_HLFCLK_DISABLE		T16A_DISABLE					// select half clock mode : disable
#define	T16A2_HLFCLK_ENABLE			T16A_ENABLE						//						  : enable

#define	T16A2_CMPBUF_DISABLE		T16A_DISABLE					// select compare buffer : disable
#define	T16A2_CMPBUF_ENABLE			T16A_ENABLE						//						 : enable

#define	T16A2_CNTMODE_REPEAT		T16A_REPEAT						// select count mode : repeat
#define	T16A2_CNTMODE_ONESHOT		T16A_ONESHOT					//					 : one-shot

// PWM timer(T16A2) run / stop control.
#define	T16A2_TIMER_STOP			T16A_STOP						// timer stop
#define	T16A2_TIMER_RUN				T16A_RUN						//		 run

// PWM timer(T16A2) comparator / capture control.
enum {
	T16A2_CAPTRG_NONE = 0,											// 0x00 : select capture trigger : none
	T16A2_CAPTRG_R,													// 0x01 :						 : rising edge
	T16A2_CAPTRG_F,													// 0x02 :						 : falling edge
	T16A2_CAPTRG_RF,												// 0x03 :						 : rising & falling edge

	T16A2_CAPTRG_MAX
};

enum {
	T16A2_TOUT_OFF = 0,												// 0x00 : select TOUT mode : off
	T16A2_TOUT_AR_BF,												// 0x01 :				   : A/rising, B/falling
	T16A2_TOUT_ARF,													// 0x02 :				   : A/toggle
	T16A2_TOUT_BRF,													// 0x03 :				   : B/toggle

	T16A2_TOUT_MAX
};

#define	T16A2_TOUT_NORMAL			T16A_NORMAL						// select TOUT invert : normal
#define	T16A2_TOUT_INVERT			T16A_INVERT						//					  : invert

#define	T16A2_MODE_COMPARATOR		T16A_COMPARATOR					// select mode : comparator
#define	T16A2_MODE_CAPTURE			T16A_CAPTURE					//			   : capture

// PWM timer(T16A2) interrupt.
#define	T16A2_CAPBOVW_DISABLE		(CAPBOWIE*T16A_DISABLE)			// capture B overwrite interrupt disable
#define	T16A2_CAPBOVW_ENABLE		(CAPBOWIE*T16A_ENABLE)			//								 enable
#define	T16A2_CAPAOVW_DISABLE		(CAPAOWIE*T16A_DISABLE)			// capture A overwrite interrupt disable
#define	T16A2_CAPAOVW_ENABLE		(CAPAOWIE*T16A_ENABLE)			//								 enable
#define	T16A2_CAPBINT_DISABLE		(CAPBIE*T16A_DISABLE)			// capture B interrupt disable
#define	T16A2_CAPBINT_ENABLE		(CAPBIE*T16A_ENABLE)			//					   enable
#define	T16A2_CAPAINT_DISABLE		(CAPAIE*T16A_DISABLE)			// capture A interrupt disable
#define	T16A2_CAPAINT_ENABLE		(CAPAIE*T16A_ENABLE)			//					   enable
#define	T16A2_CMPBINT_DISABLE		(CBIE*T16A_DISABLE)				// compare B interrupt disable
#define	T16A2_CMPBINT_ENABLE		(CBIE*T16A_ENABLE)				//					   enable
#define	T16A2_CMPAINT_DISABLE		(CAIE*T16A_DISABLE)				// compare A interrupt disable
#define	T16A2_CMPAINT_ENABLE		(CAIE*T16A_ENABLE)				//					   enable

// PWM timer(T16A2) interrupt flag.
#define	T16A2_CAPBOVW_RESET			(CAPBOWIF*T16A_RESET)			// capture B flag reset
#define	T16A2_CAPAOVW_RESET			(CAPAOWIF*T16A_RESET)			// capture A flag reset
#define	T16A2_CAPBINT_RESET			(CAPBIF*T16A_RESET)				// capture B flag reset
#define	T16A2_CAPAINT_RESET			(CAPAIF*T16A_RESET)				// capture A flag reset
#define	T16A2_CMPBINT_RESET			(CBIF*T16A_RESET)				// compare B flag reset
#define	T16A2_CMPAINT_RESET			(CAIF*T16A_RESET)				// compare A flag reset

#define	T16A2_CAPBOVW_NOTOCCURRED	(CAPBOWIF*T16A_NOTOCCURRED)		// not occurred
#define	T16A2_CAPBOVW_OCCURRED		(CAPBOWIF*T16A_OCCURRED)		// occurred
#define	T16A2_CAPAOVW_NOTOCCURRED	(CAPAOWIF*T16A_NOTOCCURRED)		// not occurred
#define	T16A2_CAPAOVW_OCCURRED		(CAPAOWIF*T16A_OCCURRED)		// occurred
#define	T16A2_CAPBINT_NOTOCCURRED	(CAPBIF*T16A_NOTOCCURRED)		// not occurred
#define	T16A2_CAPBINT_OCCURRED		(CAPBIF*T16A_OCCURRED)			// occurred
#define	T16A2_CAPAINT_NOTOCCURRED	(CAPAIF*T16A_NOTOCCURRED)		// not occurred
#define	T16A2_CAPAINT_OCCURRED		(CAPAIF*T16A_OCCURRED)			// occurred
#define	T16A2_CMPBINT_NOTOCCURRED	(CBIF*T16A_NOTOCCURRED)			// not occurred
#define	T16A2_CMPBINT_OCCURRED		(CBIF*T16A_OCCURRED)			// occurred
#define	T16A2_CMPAINT_NOTOCCURRED	(CAIF*T16A_NOTOCCURRED)			// not occurred
#define	T16A2_CMPAINT_OCCURRED		(CAIF*T16A_OCCURRED)			// occurred


/******************************************
 * definition of "struct"
 ******************************************/
// PWM timer(T16A2) mode set parameter.
struct tag_T16A2_TIM_MODE;
typedef struct tag_T16A2_TIM_MODE {
	unsigned short	hcm;											// select half clock mode
	unsigned short	ccabcnt;										// select counter
	unsigned short	cbufen;											// compare buffer enable
	unsigned short	trmd;											// select count mode
} T16A2_TIM_MODE;

// PWM timer(T16A2) comparator/capture control parameter.
struct tag_T16A2_CCCTL;
typedef struct tag_T16A2_CCCTL {
	unsigned short	captrg;											// select capture trigger
	unsigned short	toutmd;											// select TOUT mode
	unsigned short	toutinv;										// select TOUT invert
	unsigned short	ccmd;											// select comparator/capture mode
} T16A2_CCCTL;

// PWM timer(T16A2) initialize parameter.
struct tag_T16A2_INIT_PARAM;
typedef struct tag_T16A2_INIT_PARAM {
	T16A2_CCCTL		cca;											// comparator/capture A control parameter
	T16A2_CCCTL		ccb;											// comparator/capture B control parameter
	T16A2_TIM_MODE	mode;											// mode set parameter
	unsigned short	clock;											// input clock source
	unsigned short	dataA;											// compare data A
	unsigned short	dataB;											// compare data B
#ifdef S1C17624
	unsigned char	useEXCLS;										// select external clock port
	unsigned char	useToutAPort;									// select TOUTA port
	unsigned char	useToutBPort;									// select TOUTB port
#endif // end of S1C17624
} T16A2_INIT_PARAM;


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short T16A2_init(unsigned char chNo, T16A2_INIT_PARAM *param);
extern short T16A2_setTimerMode(unsigned char chNo, T16A2_TIM_MODE *mode);
extern short T16A2_setComparatorCapture(unsigned char chNo, T16A2_CCCTL *cca, T16A2_CCCTL *ccb);
extern short T16A2_getCounterData(unsigned char chNo, unsigned short *data);
extern short T16A2_setCompareData(unsigned char chNo, unsigned short dataA, unsigned short dataB);
extern short T16A2_getCaptureData(unsigned char chNo, unsigned short *dataA, unsigned short *dataB);
extern short T16A2_resetTimer(unsigned char chNo);
extern short T16A2_setTimerRun(unsigned char chNo, unsigned short selectBit);
extern short T16A2_initInt(unsigned char chNo, unsigned char intLevel);
extern short T16A2_controlInt(unsigned char chNo, unsigned short selectBit);
extern short T16A2_resetIntFlag(unsigned char chNo, unsigned short selectBit);
extern short T16A2_checkIntFlag(unsigned char chNo, unsigned short *flag);

#endif /* T16A2_API_H_ */
