/******************************************************************
 * uart_api.h
 * 
 * UART driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef UART_API_H_
#define UART_API_H_

#include <uart.h>

/******************************************
 * definition of "define"
 ******************************************/

// UART driver return code.
#define	UART_SUCCESS				 0								// success
#define	UART_INVALID_PARAMETER		-1								// invalid parameter
#define	UART_FAILURE				-2								// failure

// UART interrupt level.
enum {
	UART_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	UART_INT_LEVEL1,												// 0x01:interrupt level 1
	UART_INT_LEVEL2,												// 0x02:interrupt level 2
	UART_INT_LEVEL3,												// 0x03:interrupt level 3
	UART_INT_LEVEL4,												// 0x04:interrupt level 4
	UART_INT_LEVEL5,												// 0x05:interrupt level 5
	UART_INT_LEVEL6,												// 0x06:interrupt level 6
	UART_INT_LEVEL7,												// 0x07:interrupt level 7

	UART_INT_LEVELMAX
};

// channel number.
enum {
	UART_CH0 = 0,													// 0x00 : channel 0
#ifndef	UART_CHANNEL1
	UART_CH1,														// 0x01 : channel 1
#endif	// end of UART_CHANNEL1
	
	UART_CH_MAX
};

// UART initialize parameter.
#define	UART_DATALEN_7BIT			UART_7BIT						// select character length : 7-bit
#define	UART_DATALEN_8BIT			UART_8BIT						//						   : 8-bit
#define	UART_PARITY_EVEN			0x02							// select parity mode : even parity
#define	UART_PARITY_ODD				0x03							//					  : odd parity
#define	UART_PARITY_NONE			0x00							//					  : no parity
#define	UART_STOPBIT1				UART_1BIT						// select stop bit : 1-bit
#define	UART_STOPBIT2				UART_2BIT						//				   : 2-bit
#define	UART_CLK_INTERNAL			UART_INTERNAL					// select input clock : internal
#define	UART_CLK_EXTERNAL			UART_EXTERNAL					//					  : external

// UART enable / disable.
#define	UART_CTL_DISABLE			UART_DISABLE					// UART disable
#define	UART_CTL_ENABLE				UART_ENABLE						//		enable

// UART interrupt.
#define	UART_RXERRORINT_DISABLE		(REIEN*UART_DISABLE)			// receive error interrupt disable
#define	UART_RXERRORINT_ENABLE		(REIEN*UART_ENABLE)				//						   enable
#define	UART_RXINT_DISABLE			(RIEN*UART_DISABLE)				// receive buffer full interrupt disable
#define	UART_RXINT_ENABLE			(RIEN*UART_ENABLE)				//								 enable
#define	UART_TXINT_DISABLE			(TIEN*UART_DISABLE)				// transmit buffer empty interrupt disable
#define	UART_TXINT_ENABLE			(TIEN*UART_ENABLE)				//								   enable

// UART interrupt condition.
#define	UART_RXINT_1BYTE			UART_1BYTE						// set receive buffer full interrupt condition : 1-byte
#define	UART_RXINT_2BYTE			UART_2BYTE						//											   : 2-byte

// UART interrupt flag.
#define	UART_FRAMING_RESET			(FER*UART_RESET)				// framing error flag
#define	UART_PARITY_RESET			(PER*UART_RESET)				// parity error flag
#define	UART_OVERRUN_RESET			(OER*UART_RESET)				// overrun error flag

#define	UART_FRAMING_NOTOCCURRED	(FER*UART_NORMAL)				// framing normal
#define	UART_FRAMING_OCCURRED		(FER*UART_ERROR)				//		   error
#define	UART_PARITY_NOTOCCURRED		(PER*UART_NORMAL)				// parity normal
#define	UART_PARITY_OCCURRED		(PER*UART_ERROR)				//		  error
#define	UART_OVERRUN_NOTOCCURRED	(OER*UART_NORMAL)				// overrun normal
#define	UART_OVERRUN_OCCURRED		(OER*UART_ERROR)				//		   error
#define	UART_2BYTE_EMPTY			(RD2B*UART_RXEMPTY)				// 2-byte received empty
#define	UART_2BYTE_READY			(RD2B*UART_RXREADY)				//				   ready
#define	UART_TX_IDLE				(TRBS*UART_IDLE)				// transmit idle
#define	UART_TX_BUSY				(TRBS*UART_BUSY)				//			busy
#define	UART_RXDATA_EMPTY			(RDRY*UART_RXEMPTY)				// receive data empty
#define	UART_RXDATA_READY			(RDRY*UART_RXREADY)				//				ready
#define	UART_TXBUFFER_NOTEMPTY		(TDBE*UART_NOTEMPTY)			// transmit data buffer not empty
#define	UART_TXBUFFER_EMPTY			(TDBE*UART_EMPTY)				//						emptyd

// UART IrDA mode.
enum {
	UART_IRDA_PCLK1 = 0,											// 0x00 : select IrDA receive detection clock : PCLK1/1
	UART_IRDA_PCLK2,												// 0x01 : 									  : PCLK1/2
	UART_IRDA_PCLK4,												// 0x02 : 									  : PCLK1/4
	UART_IRDA_PCLK8,												// 0x03 : 									  : PCLK1/8
	UART_IRDA_PCLK16,												// 0x04 : 									  : PCLK1/16
	UART_IRDA_PCLK32,												// 0x05 : 									  : PCLK1/32
	UART_IRDA_PCLK64,												// 0x06 : 									  : PCLK1/64
	UART_IRDA_PCLK128,												// 0x07 : 									  : PCLK1/128
	
	UART_IRDA_MAX
};

#define	UART_IRDA_OFF				UART_OFF						// select IrDA mode : off
#define	UART_IRDA_ON				UART_ON							//					: on


/******************************************
 * definition of "struct"
 ******************************************/

// UART initialize parameter.
struct tag_UART_INIT_PARAM;
typedef struct tag_UART_INIT_PARAM {
	unsigned char	dataLen;										// select character length
	unsigned char	parity;											// select parity mode
	unsigned char	stopBit;										// select stop bit
	unsigned char	inputClk;										// select input clock
} UART_INIT_PARAM;


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short UART_init(unsigned char chNo, UART_INIT_PARAM *param);
extern short UART_setTransmitData(unsigned char chNo, unsigned char data);
extern short UART_getReceiveData(unsigned char chNo, unsigned char *data);
extern short UART_setComEnable(unsigned char chNo, unsigned char selectBit);
extern short UART_initInt(unsigned char chNo, unsigned char intLevel);
extern short UART_controlInt(unsigned char chNo, unsigned char selectBit, unsigned char condition);
extern short UART_resetIntFlag(unsigned char chNo, unsigned char selectBit);
extern short UART_checkReceiveFlag(unsigned char chNo, unsigned char *flag);
extern short UART_setIrDAmode(unsigned char chNo, unsigned char selectClk, unsigned char selectBit);


#endif	// end of UART_API_H_
