/******************************************************************
 * adc.h
 * 
 * ADC driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef ADC_H_
#define ADC_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct adc_trgBitF {
	unsigned int	adst	: 3;
	unsigned int			: 1;
	unsigned int	adts	: 2;
	unsigned int	adms	: 1;
	unsigned int	stmd	: 1;
	unsigned int	adcs	: 3;
	unsigned int	adce	: 3;
	unsigned int			: 2;
};

struct adc_ctlBitF {
	unsigned int	aden	: 1;
	unsigned int	adctl	: 1;
	unsigned int			: 2;
	unsigned int	adcie	: 1;
	unsigned int	adoie	: 1;
	unsigned int			: 2;
	unsigned int	adcf	: 1;
	unsigned int	adowe	: 1;
	unsigned int	adibs	: 1;
	unsigned int			: 1;
	unsigned int	adich	: 3;
	unsigned int			: 1;
};

struct adc_divBitF {
	unsigned int	addf	: 4;
	unsigned int			: 12;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	ADC_BASE_ADDR						(BASE_ADDR+ADC_OFFSET)


/****************************************
 ****** The Definition of ADC10SA	 ****
 ******                              ****
 ****************************************/
// A/D Conversion Result Register
#define	R16_ADC_ADD							(volatile unsigned short *)(ADC_BASE_ADDR+0x00)

#ifdef	BIT_FIELD
#define ADC10_ADD							*(volatile unsigned short *)(BASE_ADDR+0x1380)
	#define ADC10_ADD_ADD						ADC10_ADD
#endif	// end of BIT_FIELD


// A/D Trigger/Channel Select Register
#define	R16_ADC_TRG							(volatile unsigned short *)(ADC_BASE_ADDR+0x02)
	#define	ADCE_SFT							11
	#define	ADCS_SFT							8
	#define	STMD_SFT							7
	#define	ADMS_SFT							6
	#define	ADTS_SFT							4
	#define	ADST_SFT							0
	#define	ADCE								BIT(0x0007, ADCE_SFT)		// End Channel Selection
	#define	ADCS								BIT(0x0007, ADCS_SFT)		// Start Channel Selection
	#define	STMD								BIT(0x0001, STMD_SFT)		// Converted Data Store Mode
		#define	ADC_MODE0							0x0000						// mode 0
		#define	ADC_MODE1							0x0001						// mode 1
	#define	ADMS								BIT(0x0001, ADMS_SFT)		// Conversion Mode Selection
		#define	ADC_SINGLE							0x0000						// single
		#define	ADC_CONTINUOUS						0x0001						// continuous
	#define	ADTS								BIT(0x0003, ADTS_SFT)		// Conversion Trigger Selection
	#define	ADST								BIT(0x0007, ADST_SFT)		// Sampling Clock Count

#ifdef	BIT_FIELD
#define ADC10_TRG							*(volatile unsigned short *)(BASE_ADDR+0x1382)
#define BF_ADC10_TRG						(*(volatile struct adc_trgBitF *)(BASE_ADDR+0x1382))
	#define ADC10_TRG_ADCE						BF_ADC10_TRG.adce			// End channel selection
	#define ADC10_TRG_ADCS						BF_ADC10_TRG.adcs			// Start chennel selection
	#define ADC10_TRG_STMD						BF_ADC10_TRG.stmd			// Converted data store mode
	#define ADC10_TRG_ADMS						BF_ADC10_TRG.adms			// Conversion mode selection
	#define ADC10_TRG_ADTS						BF_ADC10_TRG.adts			// conversion Trigger selection
	#define ADC10_TRG_ADST						BF_ADC10_TRG.adst			// Sampling clock count
#endif	// end of BIT_FIELD


// A/D Control/Status Register
#define	R16_ADC_CTL							(volatile unsigned short *)(ADC_BASE_ADDR+0x04)
	#define	ADICH_SFT							12
	#define	ADIBS_SFT							10
	#define	ADOWE_SFT							9
	#define	ADCF_SFT							8
	#define	ADOIE_SFT							5
	#define	ADCIE_SFT							4
	#define	ADCTL_SFT							1
	#define	ADEN_SFT							0
	#define	ADICH								BIT(0x0007, ADICH_SFT)		// Internal Conversion Channel Status
	#define	ADIBS								BIT(0x0001, ADIBS_SFT)		// Internal Busy Status
		#define	ADC_IDLE							0x0000						// idle
		#define	ADC_BUSY							0x0001						// busy
	#define	ADOWE								BIT(0x0001, ADOWE_SFT)		// Overwrite Error Flag
		#define	ADC_INVLID							0x0000						// invlid
		#define	ADC_RESET							0x0001						// reset
		#define	ADC_NORMAL							0x0000						// normal
		#define	ADC_ERROR							0x0001						// error
	#define	ADCF								BIT(0x0001, ADCF_SFT)		// Conversion Complete Flag
		#define	ADC_NOTOCCURRED						0x0000						// not occurred
		#define	ADC_OCCURRED						0x0001						// occurred
	#define	ADOIE								BIT(0x0001, ADOIE_SFT)		// Overwrite Interrupt Enable
		#define	ADC_BIT_DISABLE						0x0000						// disable
		#define	ADC_BIT_ENABLE						0x0001						// enable
	#define	ADCIE								BIT(0x0001, ADCIE_SFT)		// Conversion-complete Interrupt Enable
		#define	ADC_IEN_MASK						(ADOIE | ADCIE)				// interrupt mask data
	#define	ADCTL								BIT(0x0001, ADCTL_SFT)		// Conversion Control
		#define	ADC_STOP							0x0000						// stop
		#define	ADC_START							0x0001						// start
	#define	ADEN								BIT(0x0001, ADEN_SFT)		// A/D Enable

#ifdef	BIT_FIELD
#define ADC10_CTL							*(volatile unsigned short *)(BASE_ADDR+0x1384)
#define BF_ADC10_CTL						(*(volatile struct adc_ctlBitF *)(BASE_ADDR+0x1384))
	#define ADC10_CTL_ADICH						BF_ADC10_CTL.adich			// Internal conversion channel status
	#define ADC10_CTL_ADIBS						BF_ADC10_CTL.adibs			// Internal busy status
	#define ADC10_CTL_ADOWE						BF_ADC10_CTL.adowe			// Overwrite error flag
	#define ADC10_CTL_ADCF						BF_ADC10_CTL.adcf			// Conversion-complete flag
	#define ADC10_CTL_ADOIE						BF_ADC10_CTL.adoie			// Overwrite interrupt enable
	#define ADC10_CTL_ADCIE						BF_ADC10_CTL.adcie			// Conversion-complete interrupt enable
	#define ADC10_CTL_ADCTL						BF_ADC10_CTL.adctl			// conversion control
	#define ADC10_CTL_ADEN						BF_ADC10_CTL.aden			// A/D enable
#endif	// end of BIT_FIELD


// A/D divided Rrequency Register
#define	R16_ADC_DIV							(volatile unsigned short *)(ADC_BASE_ADDR+0x06)
	#define	ADDF_SFT							0
	#define	ADDF								BIT(0x000f, ADDF_SFT)		// A/D Converter Clock Divided Frequency Select

#ifdef	BIT_FIELD
#define ADC_DIV								*(volatile unsigned short *)(BASE_ADDR+0x1386)
#define BF_ADC_DIV							(*(volatile struct adc_divBitF *)(BASE_ADDR+0x1386))
	#define ADC_DIV_ADDF						BF_ADC_DIV.addf				// A/D converter clock divided freq select
#endif	// end of BIT_FIELD


#endif	// end of ADC_H_
