/******************************************************************
 * i2cm.h
 * 
 * I2C master driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef I2CM_H_
#define I2CM_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct i2cm_enBitF {
	unsigned int	i2cen	: 1;
	unsigned int			: 15;
};

struct i2cm_ctlBitF {
	unsigned int	strt	: 1;
	unsigned int	stp		: 1;
	unsigned int			: 2;
	unsigned int	nserm	: 1;
	unsigned int			: 3;
	unsigned int	tbusy	: 1;
	unsigned int	rbusy	: 1;
	unsigned int			: 6;
};

struct i2cm_datBitF {
	unsigned int	rtdt	: 8;
	unsigned int	rtack	: 1;
	unsigned int	txe		: 1;
	unsigned int	rxe		: 1;
	unsigned int	rbrdy	: 1;
	unsigned int			: 4;
};

struct i2cm_ictlBitF {
	unsigned int	tinte	: 1;
	unsigned int	rinte	: 1;
	unsigned int			: 14;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	I2CM_BASE_ADDR						(BASE_ADDR+I2CM_OFFSET)


/***********************************************
 ****** The Definition of I2C ******************
 ****** [I2C]                 ******************
 ***********************************************/
// I2C Enable Register
#define	R16_I2CM_EN							(volatile unsigned short *)(unsigned long)(I2CM_BASE_ADDR+0x00)
	#define	I2CEN_SFT							0
	#define	I2CEN								BIT(0x0001, I2CEN_SFT)		// I2C enable
		#define	I2CM_DISABLE						0x0000						// disable
		#define	I2CM_ENABLE							0x0001						// enable

#ifdef	BIT_FIELD
#define I2C_EN								*(volatile unsigned short *)(BASE_ADDR+0x0340)
#define BF_I2C_EN							(*(volatile struct i2cm_enBitF *)(BASE_ADDR + 0x0340))
	#define I2C_EN_I2CEN						BF_I2C_EN.i2cen				// I2C enable
#endif	// end of BIT_FIELD


// I2C Control Register
#define	R16_I2CM_CTL						(volatile unsigned short *)(unsigned long)(I2CM_BASE_ADDR+0x02)
	#define	RBUSY_SFT							9
	#define	TBUSY_SFT							8
	#define	NSERM_SFT							4
	#define	STP_SFT								1
	#define	STRT_SFT							0
	#define	RBUSY								BIT(0x0001, RBUSY_SFT)		// Receive busy flag
		#define	I2CM_IDLE							0x0000						// idle
		#define	I2CM_BUSY							0x0001						// busy
	#define	TBUSY								BIT(0x0001, TBUSY_SFT)		// Transmit busy flag
	#define	NSERM								BIT(0x0001, NSERM_SFT)		// Noise remove on/off
		#define	I2CM_OFF							0x0000						// off
		#define	I2CM_ON								0x0001						// on
	#define	STP									BIT(0x0001, STP_SFT)		// Stop control
		#define	I2CM_IGNORED						0x0000						// ignored
		#define	I2CM_STOP							0x0001						// stop
	#define	STRT								BIT(0x0001, STRT_SFT)		// Start control
		#define	I2CM_START							0x0001						// start
		#define	I2CM_CONDITION_MASK					(STP | STRT)				// start / stop control mask data

#ifdef	BIT_FIELD
#define I2C_CTL								*(volatile unsigned short *)(BASE_ADDR+0x0342)
#define BF_I2C_CTL							(*(volatile struct i2cm_ctlBitF *)(BASE_ADDR + 0x0342))
	#define I2C_CTL_RBUSY						BF_I2C_CTL.rbusy			// Receive busy flag
	#define I2C_CTL_TBUSY						BF_I2C_CTL.tbusy			// Transmit busy flag
	#define I2C_CTL_NSERM						BF_I2C_CTL.nserm			// Noise remove on/off
	#define I2C_CTL_STP							BF_I2C_CTL.stp				// Stop control
	#define I2C_CTL_STRT						BF_I2C_CTL.strt				// Start control
#endif	// end of BIT_FIELD


// I2C Data Register
#define	R16_I2CM_DAT						(volatile unsigned short *)(unsigned long)(I2CM_BASE_ADDR+0x04)
	#define	RBRDY_SFT							11
	#define	RXE_SFT								10
	#define	TXE_SFT								9
	#define	RTACK_SFT							8
	#define	RTDT_SFT							0
	#define	RBRDY								BIT(0x0001, RBRDY_SFT)		// Receive buffer ready
		#define	I2CM_EMPTY							0x0000						// empty
		#define	I2CM_READY							0x0001						// ready
	#define	RXE									BIT(0x0001, RXE_SFT)		// Receive execution
		#define	I2CM_RECEIVE						0x0001						// receive
	#define	TXE									BIT(0x0001, TXE_SFT)		// Transmit execution
		#define	I2CM_TRANSMIT						0x0001						// transmit
	#define	RTACK								BIT(0x0001, RTACK_SFT)		// Receive/transmit ACK
		#define	I2CM_ACK							0x0000						// ACK
		#define	I2CM_ERROR							0x0001						// error
	#define	RTDT								BIT(0x00ff, RTDT_SFT)		// Receive/transmit data
		#define	I2CM_RX_MASK						(RXE | RTACK)				// receive mask data
		#define	I2CM_TX_MASK						(TXE | RTDT)				// transmit mask data

#ifdef	BIT_FIELD
#define I2C_DAT								*(volatile unsigned short *)(BASE_ADDR+0x0344)
#define BF_I2C_DAT							(*(volatile struct i2cm_datBitF *)(BASE_ADDR + 0x0344))
	#define I2C_DAT_RBRDY						BF_I2C_DAT.rbrdy			// Receive buffer ready
	#define I2C_DAT_RXE							BF_I2C_DAT.rxe				// Recive execution
	#define I2C_DAT_TXE							BF_I2C_DAT.txe				// Transmit execution
	#define I2C_DAT_RTACK						BF_I2C_DAT.rtack			// Receive/transmit ACK
	#define I2C_DAT_RTDT						BF_I2C_DAT.rtdt				// Receive/transmit data
#endif	// end of BIT_FIELD


// I2C Interrupt Control Register
#define	R16_I2CM_ICTL						(volatile unsigned short *)(unsigned long)(I2CM_BASE_ADDR+0x06)
	#define	RINTE_SFT							1
	#define	TINTE_SFT							0
	#define	RINTE								BIT(0x0001, RINTE_SFT)		// Receive interrupt enable
	#define	TINTE								BIT(0x0001, TINTE_SFT)		// Transmit interrupt eneble
		#define	I2CM_IEN_MASK						(RINTE | TINTE)				// receive / transmit mask data

#ifdef	BIT_FIELD
#define I2C_ICTL							*(volatile unsigned short *)(BASE_ADDR+0x0346)
#define BF_I2C_ICTL							(*(volatile struct i2cm_ictlBitF *)(BASE_ADDR + 0x0346))
	#define I2C_ICTL_RINTE						BF_I2C_ICTL.rinte			// Receive interrupt enable
	#define I2C_ICTL_TINTE						BF_I2C_ICTL.tinte			// Transmit interrupt eneble
#endif	// end of BIT_FIELD


#endif	// end of I2CM_H_
