/******************************************************************
 * itc.h
 * 
 * ITC driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef ITC_H_
#define ITC_H_

#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct itcBitF {
	unsigned int	lv_low	: 3;
	unsigned int			: 5;
	unsigned int	lv_high	: 3;
	unsigned int			: 5;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	ITC_BASE_ADDR						(BASE_ADDR+ITC_OFFSET)


/***********************************************
 ****** The Definition of Interrupt Controller *
 ****** [ITC]                                  *
 ***********************************************/
// Interrupt Level Setup Register 0
#define R16_ITC_LV0							(volatile unsigned short *)(unsigned long)(ITC_BASE_ADDR+0x06)
	#define ITC_LV_L							(0x0007)					// interrupt level bits low address
	#define ITC_LV_H							(0x0700)					// interrupt level bits high address

#define R08_ITC_LV0L						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x06)
#define R08_ITC_LV0H						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x07)
	#define ITC_LV								(0x07)						// interrupt level bits

#ifdef	BIT_FIELD
#define ITC_LV0								*(volatile unsigned short *)(BASE_ADDR+0x0306)
#define BF_ITC_LV0							(*(volatile struct itcBitF *)(BASE_ADDR+0x0306))
	#define ITC_LV0_ILV1						BF_ITC_LV0.lv_high
	#define ITC_LV0_ILV0						BF_ITC_LV0.lv_low
#endif	// end of BIT_FIELD

// Interrupt Level Setup Register 1
#define R16_ITC_LV1							(volatile unsigned short *)(unsigned long)(ITC_BASE_ADDR+0x08)
#define R08_ITC_LV1L						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x08)
#define R08_ITC_LV1H						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x09)

#ifdef	BIT_FIELD
#define ITC_LV1								*(volatile unsigned short *)(BASE_ADDR+0x0308)
#define BF_ITC_LV1							(*(volatile struct itcBitF *)(BASE_ADDR+0x0308))
	#define ITC_LV1_ILV3						BF_ITC_LV1.lv_high
	#define ITC_LV1_ILV2						BF_ITC_LV1.lv_low
#endif	// end of BIT_FIELD

// Interrupt Level Setup Register 2
#define R16_ITC_LV2							(volatile unsigned short *)(unsigned long)(ITC_BASE_ADDR+0x0a)
#define R08_ITC_LV2L						(volatile unsigned char *)((unsigned long)ITC_BASE_ADDR+0x0a)
#define R08_ITC_LV2H						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x0b)

#ifdef	BIT_FIELD
#define ITC_LV2								*(volatile unsigned short *)(BASE_ADDR+0x030a)
#define BF_ITC_LV2							(*(volatile struct itcBitF *)(BASE_ADDR+0x030a))
	#define ITC_LV2_ILV5						BF_ITC_LV2.lv_high
	#define ITC_LV2_ILV4						BF_ITC_LV2.lv_low
#endif	// end of BIT_FIELD

// Interrupt Level Setup Register 3
#define R16_ITC_LV3							(volatile unsigned short *)(unsigned long)(ITC_BASE_ADDR+0x0c)
#define R08_ITC_LV3L						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x0c)
#define R08_ITC_LV3H						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x0d)

#ifdef	BIT_FIELD
#define ITC_LV3								*(volatile unsigned short *)(BASE_ADDR+0x030c)
#define BF_ITC_LV3							(*(volatile struct itcBitF *)(BASE_ADDR+0x030c))
	#define ITC_LV3_ILV7						BF_ITC_LV3.lv_high
	#define ITC_LV3_ILV6						BF_ITC_LV3.lv_low
#endif	// end of BIT_FIELD

// Interrupt Level Setup Register 4
#define R16_ITC_LV4							(volatile unsigned short *)(unsigned long)(ITC_BASE_ADDR+0x0e)
#define R08_ITC_LV4L						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x0e)
#define R08_ITC_LV4H						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x0f)

#ifdef	BIT_FIELD
#define ITC_LV4								*(volatile unsigned short *)(BASE_ADDR+0x030e)
#define BF_ITC_LV4							(*(volatile struct itcBitF *)(BASE_ADDR+0x030e))
	#define ITC_LV4_ILV9						BF_ITC_LV4.lv_high
	#define ITC_LV4_ILV8						BF_ITC_LV4.lv_low
#endif	// end of BIT_FIELD

// Interrupt Level Setup Register 5
#define R16_ITC_LV5							(volatile unsigned short *)(unsigned long)(ITC_BASE_ADDR+0x10)
#define R08_ITC_LV5L						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x10)
#define R08_ITC_LV5H						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x11)

#ifdef	BIT_FIELD
#define ITC_LV5								*(volatile unsigned short *)(BASE_ADDR+0x0310)
#define BF_ITC_LV5							(*(volatile struct itcBitF *)(BASE_ADDR+0x0310))
	#define ITC_LV5_ILV11						BF_ITC_LV5.lv_high
	#define ITC_LV5_ILV10						BF_ITC_LV5.lv_low
#endif	// end of BIT_FIELD

// Interrupt Level Setup Register 6
#define R16_ITC_LV6							(volatile unsigned short *)(unsigned long)(ITC_BASE_ADDR+0x12)
#define R08_ITC_LV6L						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x12)
#define R08_ITC_LV6H						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x13)

#ifdef	BIT_FIELD
#define ITC_LV6								*(volatile unsigned short *)(BASE_ADDR+0x0312)
#define BF_ITC_LV6							(*(volatile struct itcBitF *)(BASE_ADDR+0x0312))
	#define ITC_LV6_ILV13						BF_ITC_LV6.lv_high
	#define ITC_LV6_ILV12						BF_ITC_LV6.lv_low
#endif	// end of BIT_FIELD

// Interrupt Level Setup Register 7
#define R16_ITC_LV7							(volatile unsigned short *)(unsigned long)(ITC_BASE_ADDR+0x14)
#define R08_ITC_LV7L						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x14)
#define R08_ITC_LV7H						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x15)

#ifdef	BIT_FIELD
#define ITC_LV7								*(volatile unsigned short *)(BASE_ADDR+0x0314)
#define BF_ITC_LV7							(*(volatile struct itcBitF *)(BASE_ADDR+0x0314))
	#define ITC_LV7_ILV15						BF_ITC_LV7.lv_high
	#define ITC_LV7_ILV14						BF_ITC_LV7.lv_low
#endif	// end of BIT_FIELD

// Interrupt Level Setup Register 8
#define R16_ITC_LV8							(volatile unsigned short *)(unsigned long)(ITC_BASE_ADDR+0x16)
#define R08_ITC_LV8L						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x16)
#define R08_ITC_LV8H						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x17)

#ifdef	BIT_FIELD
#define ITC_LV8								*(volatile unsigned short *)(BASE_ADDR+0x0316)
#define BF_ITC_LV8							(*(volatile struct itcBitF *)(BASE_ADDR+0x0316))
	#define ITC_LV8_ILV17						BF_ITC_LV8.lv_high
	#define ITC_LV8_ILV16						BF_ITC_LV8.lv_low
#endif	// end of BIT_FIELD

// Interrupt Level Setup Register 9
#define R16_ITC_LV9							(volatile unsigned short *)(unsigned long)(ITC_BASE_ADDR+0x18)
#define R08_ITC_LV9L						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x18)
#define R08_ITC_LV9H						(volatile unsigned char *)(unsigned long)(ITC_BASE_ADDR+0x19)

#ifdef	BIT_FIELD
#define ITC_LV9								*(volatile unsigned short *)(BASE_ADDR+0x0318)
#define BF_ITC_LV9							(*(volatile struct itcBitF *)(BASE_ADDR+0x0318))
	#define ITC_LV9_ILV19						BF_ITC_LV9.lv_high
	#define ITC_LV9_ILV18						BF_ITC_LV9.lv_low
#endif	// end of BIT_FIELD


#endif	// end of ITC_H_
