/**
 * @file	mux.c
 * @brief	MUX driver
 *
 * - Copyright(C) SEIKO EPSON CORPORATION 2010. All rights Reserved.
 */

#include <s1c176xx.h>

#ifdef	PE_MUX
#include <mux_api.h>
#ifdef	PE_ADC
#include <adc_api.h>
#endif	// end of PE_ADC
#ifdef	PE_SPI
#include <spi_api.h>
#endif	// end of PE_SPI
#ifdef	PE_UART
#include <uart_api.h>
#endif	// end of PE_UART
#ifdef	PE_RFC
#include <rfc_api.h>
#endif	// end of PE_RFC
#ifdef	PE_T16E
#include <t16e_api.h>
#endif	// end of PE_T16E
#ifdef	PE_T16
#include <t16_api.h>
#endif	// end of T16
#ifdef	PE_PORT
#include <port_api.h>
#endif	// PE_PORT
#ifdef	PE_T16A2
#include <t16a2_api.h>
#endif // PE_T16A2

/*
 * definition of "define"
 */
#define	MUX_INIT_DATA					0x00								// initialize data


/*
 * definition of constants
 */
struct tag_SET_PORT;
typedef struct tag_SET_PORT {
	volatile unsigned char	*port;											// port data
	unsigned char	mask;													// mask data
	unsigned char	bit;													// bit data
} SET_PORT;

#ifdef	PE_ADC
// ADC port data
static SET_PORT setADC[] = {
	{ MUX_PORT_AIN0,	MUX_MASK_AIN0,	MUX_ADC_AIN0	},
	{ MUX_PORT_AIN1,	MUX_MASK_AIN1,	MUX_ADC_AIN1	},
	{ MUX_PORT_AIN2,	MUX_MASK_AIN2,	MUX_ADC_AIN2	},
	{ MUX_PORT_AIN3,	MUX_MASK_AIN3,	MUX_ADC_AIN3	},
#ifdef	ADC_CHANNEL8
	{ MUX_PORT_AIN4,	MUX_MASK_AIN4,	MUX_ADC_AIN4	},
	{ MUX_PORT_AIN5,	MUX_MASK_AIN5,	MUX_ADC_AIN5	},
	{ MUX_PORT_AIN6,	MUX_MASK_AIN6,	MUX_ADC_AIN6	},
	{ MUX_PORT_AIN7,	MUX_MASK_AIN7,	MUX_ADC_AIN7	}
#endif	// end of ADC_CHANNEL8
};
#endif	// end of PE_ADC

#ifdef	PE_SPI
// SPI port data
static SET_PORT setSPI[][MUX_SPI_PORTMAX] = {
	{
		{ MUX_PORT_SPICLK0,	MUX_MASK_SPICLK0,	MUX_SPI_SPICLK0	},
		{ MUX_PORT_SDO0,	MUX_MASK_SDO0	,	MUX_SPI_SDO0	},
		{ MUX_PORT_SDI0,	MUX_MASK_SDI0	,	MUX_SPI_SDI0	},
		{ MUX_PORT_SPISS0,	MUX_MASK_SPISS0,	MUX_SPI_SPISS0	}
	}
};
#endif	// end of PE_SPI

#ifdef	PE_UART
#if	defined(S1C17624) || defined(S1C17622)
#define	MUX_UARTPORT_SELECT		2
#else	// S1C17604
#define	MUX_UARTPORT_SELECT		1
#endif	// end of S1C17624/S1C17622
// UART port data
static SET_PORT setUART[][MUX_UART_PORTMAX*MUX_UARTPORT_SELECT] = {
	{																		// channel 0
																				// select 0
		{ MUX_PORT_SOUT0,	MUX_MASK_SOUT0,	MUX_UART_SOUT0	},
		{ MUX_PORT_SIN0,	MUX_MASK_SIN0,	MUX_UART_SIN0	},
		{ MUX_PORT_SCLK0,	MUX_MASK_SCLK0,	MUX_UART_SCLK0	},
#if	defined(S1C17624) || defined(S1C17622)
																				// select 1
		{ MUX_PORT_SOUT0,	MUX_MASK_SOUT0,	MUX_UART_SOUT0	},
		{ MUX_PORT_SIN0,	MUX_MASK_SIN0,	MUX_UART_SIN0	},
		{ MUX_PORT_SCLK0,	MUX_MASK_SCLK0,	MUX_UART_SCLK0	}
#endif	// end of S1C17624/S1C17622
	},
#ifdef	UART_CHANNEL2
	{																		// channel 1
																				// select 0
		{ MUX_PORT_SOUT1_0,	MUX_MASK_SOUT1_0,	MUX_UART_SOUT1_0	},
		{ MUX_PORT_SIN1_0,	MUX_MASK_SIN1_0,	MUX_UART_SIN1_0		},
		{ MUX_PORT_SCLK1_0,	MUX_MASK_SCLK1_0,	MUX_UART_SCLK1_0	},
#if	defined(S1C17624) || defined(S1C17622)
																				// select 1
		{ MUX_PORT_SOUT1_1,	MUX_MASK_SOUT1_1,	MUX_UART_SOUT1_1	},
		{ MUX_PORT_SIN1_1,	MUX_MASK_SIN1_1,	MUX_UART_SIN1_1		},
		{ MUX_PORT_SCLK1_1,	MUX_MASK_SCLK1_1,	MUX_UART_SCLK1_1	}
#endif	// end of S1C17624/S1C17622
	}
#endif	// end of UART_CHANNEL2
};
#endif	// end of PE_UART

#ifdef	PE_RFC
// RFC port data
static SET_PORT setRFC[][MUX_RFC_PORTMAX] = {
	{																		// channel 0
		{ MUX_PORT_RFIN0,	MUX_MASK_RFIN0,		MUX_RFC_RFIN0	},
		{ MUX_PORT_REF0,	MUX_MASK_REF0,		MUX_RFC_REF0	},
		{ MUX_PORT_SENA0,	MUX_MASK_SENA0,		MUX_RFC_SENA0	},
		{ MUX_PORT_SENB0,	MUX_MASK_SENB0,		MUX_RFC_SENB0	}
	},
#ifdef	RFC_CHANNEL2
	{																		// channel 1
		{ MUX_PORT_RFIN1,	MUX_MASK_RFIN1,		MUX_RFC_RFIN1	},
		{ MUX_PORT_REF1,	MUX_MASK_REF1,		MUX_RFC_REF1	},
		{ MUX_PORT_SENA1,	MUX_MASK_SENA1,		MUX_RFC_SENA1	},
		{ MUX_PORT_SENB1,	MUX_MASK_SENB1,		MUX_RFC_SENB1	}
	}
#endif	// end of RFC_CHANNEL2
};
#endif	// end of PE_RFC

#ifdef	PE_I2CM
// I2C master port data
static SET_PORT setI2CM[][MUX_I2CM_PORTMAX] = {
	{																		// select 0
		{ MUX_PORT_SCL0_0,	MUX_MASK_SCL0_0,	MUX_I2CM_SCL0_0	},
		{ MUX_PORT_SDA0_0,	MUX_MASK_SDA0_0,	MUX_I2CM_SDA0_0	}
	},
	{																		// select 1
		{ MUX_PORT_SCL0_1,	MUX_MASK_SCL0_1,	MUX_I2CM_SCL0_1	},
		{ MUX_PORT_SDA0_1,	MUX_MASK_SDA0_1,	MUX_I2CM_SDA0_1	}
	}
};
#endif	// end of PE_I2CM

#ifdef	PE_I2CS
// I2C slave port data
static SET_PORT setI2CS[][MUX_I2CS_PORTMAX] = {
	{																		// select 0
		{ MUX_PORT_SCL1_0,	MUX_MASK_SCL1_0,	MUX_I2CS_SCL1_0	},
		{ MUX_PORT_SDA1_0,	MUX_MASK_SDA1_0,	MUX_I2CS_SDA1_0	},
		{ MUX_PORT_BFR_0,	MUX_MASK_BFR_0,		MUX_I2CS_BFR_0	}
	},
#if	defined(S1C17624) || defined(S1C17622)
	{																		// select 1
		{ MUX_PORT_SCL1_1,	MUX_MASK_SCL1_1,	MUX_I2CS_SCL1_1	},
		{ MUX_PORT_SDA1_1,	MUX_MASK_SDA1_1,	MUX_I2CS_SDA1_1	},
		{ MUX_PORT_BFR_1,	MUX_MASK_BFR_1,		MUX_I2CS_BFR_1	}
	}
#endif	// end of S1C17624/S1C17622
};
#endif	// end of PE_I2CS

#ifdef	PE_T16E
// PWM timer port data
static SET_PORT setT16E[][MUX_T16E_PORTMAX] = {
	{																		// channel 0
		{ MUX_PORT_TOUT3,	MUX_MASK_TOUT3,		MUX_T16E_TOUT3	},
		{ MUX_PORT_TOUTN3,	MUX_MASK_TOUTN3,	MUX_T16E_TOUTN3	}
	}
};
#endif	// end of PE_T16E

#ifdef	PE_T16
// 16-bit timer port data
static SET_PORT setT16[] = {
	{ MUX_PORT_EXCL0,	MUX_MASK_EXCL0,	MUX_T16_EXCL0	},
	{ MUX_PORT_EXCL1,	MUX_MASK_EXCL1,	MUX_T16_EXCL1	},
	{ MUX_PORT_EXCL2,	MUX_MASK_EXCL2,	MUX_T16_EXCL2	}
};
#endif	// end of PE_T16


/*
 * Declarations of function prototype
 */
#if	defined(PE_ADC) || defined(PE_SPI) || defined(PE_UART) \
	|| defined(PE_I2CM) || defined(PE_T16E) || defined(PE_T16)
static void setPort(SET_PORT *portData, unsigned char sw);
#endif

#ifdef	PE_PORT
void MUX_init(void);
#endif	// end of PE_PORT
#ifdef	PE_REMC
short MUX_setREMCport(unsigned char sw);
#endif	// end of PE_REMC
#ifdef	PE_ADC
short MUX_setADCport(unsigned char use, unsigned short startCh, unsigned short endCh, unsigned char sw);
#endif	// end of PE_ADC
#ifdef	PE_SPI
short MUX_setSPIport(unsigned char chNo, unsigned char sw);
#endif	// end of PE_SPI
#ifdef	PE_UART
short MUX_setUARTport(unsigned char chNo, unsigned char inputClk, MUX_USE_UARTPORT *use);
#endif	// end of PE_UART
#ifdef	PE_RFC
short MUX_setRFCport(unsigned char chNo, MUX_USE_RFCPORT *use, unsigned char sw);
#endif	// end of PE_RFC
#ifdef	PE_I2CM
short MUX_setI2CMport(unsigned char selectNo, unsigned char sw);
#endif	// end of PE_I2CM
#ifdef	PE_I2CS
short MUX_setI2CSport(MUX_USE_I2CSPORT *use);
#endif	// end of PE_I2CS
#ifdef	PE_CLG_OSC
short MUX_setOSCport(unsigned char useFout1, unsigned char useFouth, unsigned char sw);
#endif	// end of PE_CLG_OSC
#ifdef	PE_T16E
short MUX_setT16Eport(unsigned char chNo, unsigned char sw);
#endif	// end of PE_T16E
#ifdef	PE_LCD
short MUX_setLCDport(MUX_USE_LCDPORT *use);
#endif	// end of PE_LCD
#ifdef	PE_T8OSC1
short MUX_setT8OSC1port(MUX_USE_T8OSC1PORT *use);
#endif	// end of PE_T8OSC1
short MUX_setDBGport(unsigned char sw);
#ifdef	PE_T16
short MUX_setT16port(unsigned char chNo, unsigned char sw);
#endif	// end of PE_T16
#ifdef	PE_T16A2
short MUX_setT16A2port(unsigned char chNo, MUX_USE_T16A2PORT *use, unsigned char sw);
#endif	// end of PE_T16A2

#if	defined(PE_ADC) || defined(PE_SPI) || defined(PE_UART) \
	|| defined(PE_I2CM) || defined(PE_T16E) || defined(PE_T16)
/*
 * set a port data
 * param: SET_PORT *portData						port data
 * param: unsigned char sw							select port / function
 * return: void
 * history: 2009/12/25
 */
static void setPort(SET_PORT *portData, unsigned char sw)
{
	// port set
	RegModify(portData->port, portData->mask, (portData->bit * sw));		// use channel port set
}
#endif

#ifdef	PE_PORT
/**
 * @brief	MUX initialize.
 * - 1. set default value in all input/outpu ports.
 *
 * @return	none
 * @date	2009/12/25
 */
void MUX_init(void)
{
	unsigned char	i;														// counter

	// MUX initialize data set
	for(i = 0; i < PORT_NO_MAX; i++) {
		RegWrite((R08_P0L_PMUX + (i * 2)), MUX_INIT_DATA);					// Px[3:0] initialize
		RegWrite((R08_P0H_PMUX + (i * 2)), MUX_INIT_DATA);					// Px[7:4] initialize
	}
}
#endif	// end of PE_PORT

#ifdef	PE_REMC
/**
 * @brief	set REMC ports.
 * - 1. check parameters.
 * - 2. set input/output ports in the case of MUX_OFF,
 *		set REMC ports in the case of MUX_ON.
 *
 * @param	sw; unsigned char: 				select port function
 * -		MUX_OFF : set input/output ports
 * -		MUX_ON  : set REMC ports
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2009/12/25
 */
short MUX_setREMCport(unsigned char sw)
{
	// parameter check
	if(sw > MUX_ON) {
		return	MUX_INVALID_PARAMETER;
	}

	// REMC port set
	RegModify(MUX_PORT_REMO, MUX_MASK_REMO, (MUX_REMC_REMO * sw));			// REMO port set
	RegModify(MUX_PORT_REMI, MUX_MASK_REMI, (MUX_REMC_REMI * sw));			// REMI port set

	return	MUX_SUCCESS;
}
#endif	// end of PE_REMC

#ifdef	PE_ADC
/**
 * @brief	set ADC ports.
 * - 1. check parameters.
 * - 2. set a xADTRG in the case of use external trigger.
 * - 3. set input/output ports in the case of MUX_OFF,
 *		set ADC ports in the case of MUX_ON.
 *		(from conversion start channel to conversion end channel.)
 *
 * @param	use; unsigned char: 			select external trigger
 * -		MUX_ADTRG_OFF : external trigger is not use
 * -		MUX_ADTRG_ON  : external trigger is use
 * @param	startCh; unsigned short: 		select start channel number
 * -		ADC_CH0 : conversion start channel number 0
 * -		ADC_CH1 : conversion start channel number 1
 * -		ADC_CH2 : conversion start channel number 2
 * -		ADC_CH3 : conversion start channel number 3
 * -		ADC_CH4 : conversion start channel number 4
 * -		ADC_CH5 : conversion start channel number 5
 * -		ADC_CH6 : conversion start channel number 6
 * -		ADC_CH7 : conversion start channel number 7
 * @param	endCh; unsigned short: 			select end channel number
 * -		ADC_CH0 : conversion end channel number 0
 * -		ADC_CH1 : conversion end channel number 1
 * -		ADC_CH2 : conversion end channel number 2
 * -		ADC_CH3 : conversion end channel number 3
 * -		ADC_CH4 : conversion end channel number 4
 * -		ADC_CH5 : conversion end channel number 5
 * -		ADC_CH6 : conversion end channel number 6
 * -		ADC_CH7 : conversion end channel number 7
 * @param	sw; unsigned char: 				select port function
 * -		MUX_OFF : set input/output ports
 * -		MUX_ON  : set ADC ports
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2009/12/25
 */
short MUX_setADCport(unsigned char use, unsigned short startCh, unsigned short endCh, unsigned char sw)
{
	unsigned short	ch;														// select channel counter
	SET_PORT		*portData = &setADC[startCh];							// port data

	// parameter check
	if(	(use > MUX_ADTRG_ON) ||
		(startCh >= ADC_CH_MAX) ||
		(endCh >= ADC_CH_MAX) ||
		(startCh > endCh) ||
		(sw > MUX_ON) ) {
			return	MUX_INVALID_PARAMETER;
	}

	// ADC port set
	if(use == MUX_ADTRG_ON) {												// select external trigger
		RegModify(MUX_PORT_ADTRG, MUX_MASK_ADTRG, (MUX_ADC_ADTRG * sw));
	}

	for(ch = startCh; ch <= endCh; ch++) {
		setPort(portData, sw);											// use channel port set
		++portData;
	}

	return	MUX_SUCCESS;
}
#endif	// end of PE_ADC

#ifdef	PE_SPI
/**
 * @brief	set SPI ports.
 * - 1. check parameters.
 * - 2. set input/output ports in the case of MUX_OFF,
 *		set SPI ports in the case of MUX_ON.
 *
 * @param	chNo; unsigned char: 			select channel number
 * -		SPI_CH0 : SPI channel number 0
 * @param	sw; unsigned char: 				select port function
 * -		MUX_OFF : set input/output ports
 * -		MUX_ON  : set SPI ports
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2009/12/25
 */
short MUX_setSPIport(unsigned char chNo, unsigned char sw)
{
	unsigned char	port;													// port data number
	SET_PORT		*portData = &setSPI[chNo][0];							// port data

	// parameter check
	if(	(chNo >= SPI_CH_MAX) ||
		(sw > MUX_ON) ) {
			return	MUX_INVALID_PARAMETER;
	}

	// SPI port set
	for(port = 0; port < MUX_SPI_PORTMAX; port++) {
		setPort(portData, sw);
		++portData;
	}

	return	MUX_SUCCESS;
}
#endif	// end of PE_SPI

#ifdef	PE_UART
/**
 * @brief	set UART ports.
 * - 1. check parameters.
 * - 2. set input/output ports in the case of MUX_OFF,
 *		set UART ports in the case of MUX_ON.
 *		(set a SCLK in the case of use external clock.)
 *
 * @param	chNo; unsigned char: 			select channel number
 * -		UART_CH0 : UART channel number 0
 * -		UART_CH1 : UART channel number 1
 * @param	inputClk; unsigned char: 		select input clock
 * -		MUX_UART_CLK_INTERNAL internal clock
 * -		MUX_UART_CLK_EXTERNAL external clock
 * @param	*use; MUX_USE_UARTPORT: 		select use port
 * -		sw; unsigned char;				select port function
 * 	-		MUX_OFF : set input/output ports
 * 	-		MUX_ON  : set UART ports
 * -		selectNo : unsigned char:		select number(only S1C17624/S1C17622)
 * 	-		MUX_UART_CH1_0 : select port number 0 in case CH1
 * 	-		MUX_UART_CH1_1 : select port number 1 in case CH1
 * 	-		MUX_UART_CH0 : in case CH0
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2010/04/12 : Fix parameter.
 * @version
 * -		2009/12/25
 */
short MUX_setUARTport(unsigned char chNo, unsigned char inputClk, MUX_USE_UARTPORT *use)
{
	unsigned char	port;													// port data number						// port data
	SET_PORT	*portData;

	// parameter check
	if(	(chNo >= UART_CH_MAX) ||
		(inputClk > MUX_UART_CLK_EXTERNAL) ||
#if	defined(S1C17624) || defined(S1C17622)
		(use->selectNo >= MUX_UART_CH_MAX) ||
#endif	// end of S1C17624/S1C17622
		(use->sw > MUX_ON) ) {
			return	MUX_INVALID_PARAMETER;
	}

#if	defined(S1C17624) || defined(S1C17622)
	if(chNo == UART_CH1) {
		portData = &setUART[chNo][(use->selectNo)*MUX_UART_PORTMAX];	// select port number
	} else {
		portData = &setUART[chNo][0];
	}
#else	// S1C17604
		portData = &setUART[chNo][0];
#endif	// end of S1C17624/S1C17622

	// UART port set
	for(port = 0; port < (MUX_UART_PORTMAX - 1); port++) {					// set SCLK only external clock use
		setPort(portData, use->sw);
		++portData;
	}
	if(inputClk == MUX_UART_CLK_EXTERNAL) {
		setPort(portData, use->sw);												// use external clock
		++portData;
	}

	return	MUX_SUCCESS;
}
#endif	// end of PE_UART

#ifdef	PE_RFC
/**
 * @brief	set RFC ports.
 * - 1. check parameters.
 * - 2. set input/output ports in the case of MUX_OFF,
 *		set RFC ports in the case of MUX_ON.
 *
 * @param	chNo; unsigned char: 			select channel number
 * -		RFC_CH0 : RFC channel number 0
 * -		RFC_CH1 : RFC channel number 1
 * @param	*use; MUX_USE_RFCPORT: 			select use port
 * -		useRfin;  unsigned char:		select external clock
 * 	-			MUX_RFIN_OFF : external clock is not use
 * 	-			MUX_RFIN_ON  : external clock is use
 * -		useRef; unsigned char:			select reference
 * 	-			MUX_REF_OFF : reference is not use
 * 	-			MUX_REF_ON  : reference is use
 * -		useSenA; unsigned char:			select sensor A
 * 	-			MUX_SENA_OFF : sensor A is not use
 * 	-			MUX_SENA_ON  : sensor A is use
 * -		useSenB; unsigned char:			select sensor B
 * 	-			MUX_SENB_OFF : sensor B is not use
 * 	-			MUX_SENB_ON  : sensor B is use
 * -		useRfclk; unsigned char:		select RFCLK monitor output
 * 	-			MUX_RFCLK_OFF : RFCLK monitor output is not use
 * 	-			MUX_RFCLK_ON  : RFCLK monitor output is use
 * -		useRFCLKS; unsigned char:		select RFCLK port
 * 	-			MUX_RFCLK_P36 : use P36 for RFCLK
 * 	-			MUX_RFCLK_P46 : use P46 for RFCLK
 * 	-			MUX_RFCLK_POFF : RFCLK is not use
 * @param	sw; unsigned char: 				select port function
 * -		MUX_OFF : set input/output ports
 * -		MUX_ON  : set RFC ports
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2010/04/12 : Fix parameter.
 * @version
 * -		2009/12/25
 */
short MUX_setRFCport(unsigned char chNo, MUX_USE_RFCPORT *use, unsigned char sw)
{
	SET_PORT	*portData = &setRFC[chNo][0];								// port data

	// parameter check
	if(	(chNo >= RFC_CH_MAX) ||
		(use->useRfin > MUX_RFIN_ON) ||
		(use->useRef > MUX_REF_ON) ||
		(use->useSenA > MUX_SENA_ON) ||
		(use->useSenB > MUX_SENB_ON) ||
		(use->useRfclk > MUX_RFCLK_ON) ||
#if	defined(S1C17624) || defined(S1C17622)
		(use->useRFCLKS >= MUX_RFCLK_MAX) ||
#endif	// end of S1C17624/S1C17622
		(sw > MUX_ON) ) {
			return	MUX_INVALID_PARAMETER;
	}

	// RFC port set
	if(use->useRfin == MUX_RFIN_ON) {
		RegModify(portData->port, portData->mask, (portData->bit * sw));
	}
	portData++;
	if(use->useRef == MUX_REF_ON) {
		RegModify(portData->port, portData->mask, (portData->bit * sw));
	}
	portData++;
	if(use->useSenA == MUX_SENA_ON) {
		RegModify(portData->port, portData->mask, (portData->bit * sw));
	}
	portData++;
	if(use->useSenB == MUX_SENB_ON) {
		RegModify(portData->port, portData->mask, (portData->bit * sw));
	}
	portData++;
	if(use->useRfclk == MUX_RFCLK_ON) {
#if	defined(S1C17624) || defined(S1C17622)
		switch(use->useRFCLKS) {
		case	MUX_RFCLK_P36:
			RegModify(MUX_PORT_RFCLKO_0, MUX_MASK_RFCLKO_0, (MUX_RFC_RFCLKO_0 * sw));
			break;
		case	MUX_RFCLK_P46:
			RegModify(MUX_PORT_RFCLKO_1, MUX_MASK_RFCLKO_1, (MUX_RFC_RFCLKO_1 * sw));
			break;
		case	MUX_RFCLK_P36_P46:
			RegModify(MUX_PORT_RFCLKO_0, MUX_MASK_RFCLKO_0, (MUX_RFC_RFCLKO_0 * sw));
			RegModify(MUX_PORT_RFCLKO_1, MUX_MASK_RFCLKO_1, (MUX_RFC_RFCLKO_1 * sw));
			break;
		default:
			break;
		}
#else	// S1C17604
		RegModify(MUX_PORT_RFCLKO_0, MUX_MASK_RFCLKO_0, (MUX_RFC_RFCLKO_0 * sw));
#endif	// end of S1C17624/S1C17622
	}

	return	MUX_SUCCESS;
}
#endif	// end of PE_RFC

#ifdef	PE_I2CM
/**
 * @brief	set I2C master ports.
 * - 1. check parameters.
 * - 2. set input/output ports in the case of MUX_OFF,
 *		set I2C master ports in the case of MUX_ON.
 *
 * @param	selectNo; unsigned char: 		select number
 * -		MUX_I2CM_0 : port select number 0
 * -		MUX_I2CM_1 : port select number 1
 * @param	sw; unsigned char: 				select port function
 * -		MUX_OFF : set input/output ports
 * -		MUX_ON  : set I2C master ports
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2009/12/25
 */
short MUX_setI2CMport(unsigned char selectNo, unsigned char sw)
{
	unsigned char	port;													// port data number
	SET_PORT		*portData = &setI2CM[selectNo][0];						// port data

	// parameter check
	if(	(selectNo > MUX_I2CM_1) ||
		(sw > MUX_ON) ) {
			return	MUX_INVALID_PARAMETER;
	}

	// I2C master port set
	for(port = 0; port < MUX_I2CM_PORTMAX; port++) {
		setPort(portData, sw);
		++portData;
	}

	return	MUX_SUCCESS;
}
#endif	// end of PE_I2CM

#ifdef	PE_I2CS
/**
 * @brief	set I2C slave ports.
 * - 1. check parameters.
 * - 2. set input/output ports in the case of MUX_OFF,
 *		set I2C slave ports in the case of MUX_ON.
 *
 * @param	*use; MUX_USE_I2CSPORT: 			select port
 * -		sw : unsigned char					select port function
 * 	-		MUX_OFF : set input/output ports
 * 	-		MUX_ON  : set I2C slave ports
 * -		selectNo : unsigned char			select number(only S1C17624/S1C17622)
 * 	-		MUX_I2CS_0 : port select number 0
 * 	-		MUX_I2CS_1 : port select number 1
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2010/04/15 : Fix parameter.
 * @version
 * -		2009/12/25
 */
short MUX_setI2CSport(MUX_USE_I2CSPORT *use)
{
	unsigned char	port;
	SET_PORT		*portData;					// port data

	// parameter check
	if(use->sw > MUX_ON) {
		return	MUX_INVALID_PARAMETER;
	}

#if	defined(S1C17624) || defined(S1C17622)
	if(use->selectNo > MUX_I2CS_1) {
		return MUX_INVALID_PARAMETER;
	}

	portData = &setI2CS[use->selectNo][0];
#else	// end of S1C17624/S1C17622
	portData = &setI2CS[0][0];
#endif	// end of S1C17624/S1C17622
	// I2C slave port set
	for(port = 0; port < MUX_I2CS_PORTMAX; port++) {
		setPort(portData, use->sw);
		++portData;
	}

	return	MUX_SUCCESS;
}
#endif	// end of PE_I2CS

#ifdef	PE_CLG_OSC
/**
 * @brief	set OSC ports.
 * - 1. check parameters.
 * - 2. set input/output ports in the case of MUX_OFF,
 *		set OSC ports in the case of MUX_ON.
 *
 * @param	useFout1; unsigned char: 		select FOUT1
 * -		MUX_FOUT1_OFF : FOUT1 is not use
 * -		MUX_FOUT1_ON  : FOUT1 is use
 * @param	useFouth; unsigned char: 		select FOUTH
 * -		MUX_FOUTH_OFF : FOUTH is not use
 * -		MUX_FOUTH_ON  : FOUTH is use
 * @param	sw; unsigned char: 				select port function
 * -		MUX_OFF : set input/output ports
 * -		MUX_ON  : set OSC ports
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2009/12/25
 */
short MUX_setOSCport(unsigned char useFout1, unsigned char useFouth, unsigned char sw)
{
	// parameter check
	if(	(useFout1 > MUX_FOUT1_ON) ||
		(useFouth > MUX_FOUTH_ON) ||
		(sw > MUX_ON) ) {
			return	MUX_INVALID_PARAMETER;
	}

	// OSC port set
	if(useFout1 == MUX_FOUT1_ON) {
		RegModify(MUX_PORT_FOUT1, MUX_MASK_FOUT1, (MUX_OSC_FOUT1 * sw));
	}
	if(useFouth == MUX_FOUTH_ON) {
		RegModify(MUX_PORT_FOUTH, MUX_MASK_FOUTH, (MUX_OSC_FOUTH * sw));
	}

	return	MUX_SUCCESS;
}
#endif	// end of PE_CLG_OSC

#ifdef	PE_T16E
/**
 * @brief	set PWM timer ports.
 * - 1. check parameters.
 * - 2. set input/output ports in the case of MUX_OFF,
 *		set PWM timer ports in the case of MUX_ON.
 *
 * @param	chNo; unsigned char: 			select channel number
 * -		T16E_CH0 : PWM timer channel number 0
 * @param	sw; unsigned char: 				select port function
 * -		MUX_OFF : set input/output ports
 * -		MUX_ON  : set PWM timer ports
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2009/12/25
 */
short MUX_setT16Eport(unsigned char chNo, unsigned char sw)
{
	unsigned char	port;													// port data number
	SET_PORT		*portData = &setT16E[chNo][0];							// port data

	// parameter check
	if(	(chNo >= T16E_CH_MAX) ||
		(sw > MUX_ON) ) {
			return	MUX_INVALID_PARAMETER;
	}

	// PWM timer port set
	for(port = 0; port < MUX_T16E_PORTMAX; port++) {
		setPort(portData, sw);
		++portData;
	}

	return	MUX_SUCCESS;
}
#endif	// end of PE_T16E

#ifdef	PE_LCD
/**
 * @brief	set LCD ports.
 * - 1. check parameters.
 * - 2. set input/output ports in the case of MUX_OFF,
 *		set LCD ports in the case of MUX_ON.
 *
 * @param	*use; MUX_USE_LCDPORT: 				select port
 * -		sw; unsigned char:					select port function
 * 	-		MUX_OFF : set input/output ports
 * 	-		MUX_ON  : set LCD ports
 * -		useLFRO; unsigned char:				select LFRO port(only S1C17624/S1C17622)
 * 	-		MUX_LFRO_P37 : select P37 for LFRO
 * 	-		MUX_LFRO_P54 : select P54 for LFRO
 * 	-		MUX_LFRO_P37_P54 : select P37 and P54 for LFRO
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2010/04/12 : Fix parameter.
 * @version
 * -		2009/12/25
 */
short MUX_setLCDport(MUX_USE_LCDPORT *use)
{
	// parameter check
	if(use->sw > MUX_ON) {
		return	MUX_INVALID_PARAMETER;
	}

#if	defined(S1C17624) || defined(S1C17622)
	if(use->useLFRO >= MUX_LFRO_MAX) {
		return MUX_INVALID_PARAMETER;
	}

	// LCD port set
	switch(use->useLFRO) {
	case	MUX_LFRO_P37:
		RegModify(MUX_PORT_LFRO_0, MUX_MASK_LFRO_0, (MUX_LCD_LFRO_0 * use->sw));
		break;
	case	MUX_LFRO_P54:
		RegModify(MUX_PORT_LFRO_1, MUX_MASK_LFRO_1, (MUX_LCD_LFRO_1 * use->sw));
		break;
	case	MUX_LFRO_P37_P54:
		RegModify(MUX_PORT_LFRO_0, MUX_MASK_LFRO_0, (MUX_LCD_LFRO_0 * use->sw));
		RegModify(MUX_PORT_LFRO_1, MUX_MASK_LFRO_1, (MUX_LCD_LFRO_1 * use->sw));
		break;
	default:
		break;
	}
#else	// S1C17604
	// LCD port set
	RegModify(MUX_PORT_LFRO_0, MUX_MASK_LFRO_0, (MUX_LCD_LFRO_0 * use->sw));
#endif	// end of S1C17624/S1C17622

	return	MUX_SUCCESS;
}
#endif	// end of PE_LCD

#ifdef	PE_T8OSC1
/**
 * @brief	set 8-bit OSC1 timer ports.
 * - 1. check parameters.
 * - 2. set input/output ports in the case of MUX_OFF,
 *		set 8-bit OSC1 timer ports in the case of MUX_ON.
 *
 * @param	*usc; MUX_USE_T8OSC1PORT: 				select port
 * -		sw; unsigned char :						select port function
 * 	-		MUX_OFF : set input/output ports
 * 	-		MUX_ON  : set 8-bit OSC1 timer ports
 * -		useTOUT4; unsigned char :				select TOUT4 port(only S1C17624/S1C17622)
 * 	-		MUX_TOUT4_P37 : select P37 for TOUT4
 * 	-		MUX_TOUT4_P47 : select P47 for TOUT4
 * 	-		MUX_TOUT4_P37_P47 : select P37 and P47 for TOUT4
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2010/04/12 : Fix parameter.
 * @version
 * -		2009/12/25
 */
short MUX_setT8OSC1port(MUX_USE_T8OSC1PORT *use)
{
	// parameter check
	if(use->sw > MUX_ON) {
		return	MUX_INVALID_PARAMETER;
	}

#if defined(S1C17624) || defined(S1C17622)
	if(use->useTOUT4 >= MUX_TOUT4_MAX) {
		return MUX_INVALID_PARAMETER;
	}

	// 8-bit OSC1 port set
	switch(use->useTOUT4) {
	case	MUX_TOUT4_P37:
		RegModify(MUX_PORT_TOUT4_0, MUX_MASK_TOUT4_0, (MUX_T8OSC1_TOUT4_0 * use->sw));
		break;
	case	MUX_TOUT4_P47:
		RegModify(MUX_PORT_TOUT4_1, MUX_MASK_TOUT4_1, (MUX_T8OSC1_TOUT4_1 * use->sw));
		break;
	case	MUX_TOUT4_P37_P47:
		RegModify(MUX_PORT_TOUT4_0, MUX_MASK_TOUT4_0, (MUX_T8OSC1_TOUT4_0 * use->sw));
		RegModify(MUX_PORT_TOUT4_1, MUX_MASK_TOUT4_1, (MUX_T8OSC1_TOUT4_1 * use->sw));
		break;
	default:
		break;
	}

#else	// S1C17622
	// 8-bit OSC1 port set
	RegModify(MUX_PORT_TOUT4_0, MUX_MASK_TOUT4_0, (MUX_T8OSC1_TOUT4_0 * use->sw));
#endif	// end of S1C17624/S1C17622

	return	MUX_SUCCESS;
}
#endif	// end of PE_T8OSC1

/**
 * @brief	set debug ports.
 * - 1. check parameters.
 * - 2. set debug ports in the case of MUX_OFF,
 *		set input/output ports in the case of MUX_ON.
 *
 * @param	sw; unsigned char: 				select port function
 * -		MUX_OFF : set debug ports
 * -		MUX_ON  : set input/output ports
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2009/12/25
 */
short MUX_setDBGport(unsigned char sw)
{
	// parameter check
	if(sw > MUX_ON) {
		return	MUX_INVALID_PARAMETER;
	}

	// debug port set
	RegModify(MUX_PORT_P41, MUX_MASK_P41, (MUX_DBG_P41 * sw));
	RegModify(MUX_PORT_P42, MUX_MASK_P42, (MUX_DBG_P42 * sw));
	RegModify(MUX_PORT_P43, MUX_MASK_P43, (MUX_DBG_P43 * sw));


	return	MUX_SUCCESS;
}

#ifdef	PE_T16
/**
 * @brief	set 16-bit timer ports.
 * - 1. check parameters.
 * - 2. set input/output ports in the case of MUX_OFF,
 *		set 16-bit timer ports in the case of MUX_ON.
 *
 * @param	chNo; unsigned char: 			select channel number
 * -		T16_CH0 : 16-bit timer channel number 0
 * -		T16_CH1 : 16-bit timer channel number 1
 * -		T16_CH2 : 16-bit timer channel number 2
 * @param	sw; unsigned char: 				select port function
 * -		MUX_OFF : set input/output ports
 * -		MUX_ON  : set 16-bit timer ports
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2009/12/25
 */
short MUX_setT16port(unsigned char chNo, unsigned char sw)
{
	SET_PORT	*portData = &setT16[chNo];									// port data

	// parameter check
	if(	(chNo >= T16_CH_MAX) ||
		(sw > MUX_ON) ) {
			return	MUX_INVALID_PARAMETER;
	}

	// 16-bit timer port set
	setPort(portData, sw);

	return	MUX_SUCCESS;
}
#endif	// end of PE_T16

#ifdef	PE_T16A2
/**
 * @brief	set PWM timer(T16A2) ports.
 * - 1. check parameters.
 * - 2. set input/output ports in the case of MUX_OFF,
 *		set PWM timer(T16A2) ports in the case of MUX_ON.
 *
 * @param	chNo; unsigned char: 			select channel number
 * -		T16A2_CH0 : T16A2 timer channel number 0
 * -		T16A2_CH1 : T16A2 timer channel number 1
 * -		T16A2_CH2 : T16A2 timer channel number 2
 * @param	*use; MUX_USE_T16A2PORT: 		select use port
 * -		useEXCL; unsigned char: 		select external clock
 * 	-			MUX_EXCL_OFF : external clock is not use
 * 	-			MUX_EXCL_ON  : external clock is use
 * -		useToutA; unsigned char: 		select TOUTA
 * 	-			MUX_TOUTA_OFF : TOUTA is not use
 * 	-			MUX_TOUTA_ON  : TOUTA is use
 * -		useToutB; unsigned char: 		select TOUTB
 * 	-			MUX_TOUTB_OFF : TOUTB is not use
 * 	-			MUX_TOUTB_ON  : TOUTB is use
 * -		useEXCLS; unsigned char	: select external clock port(only S1C17624)
 *  -			MUX_EXCLXS_OFF : case not use external clock
 *  -			MUX_EXCL5S_CH0_P36 : case use external clock by P36 for T16A2 Ch.0
 *  -			MUX_EXCL5S_CH0_P47 : case use external clock by P47 for T16A2 Ch.0
 *  -			MUX_EXCL6S_CH1_P37 : case use external clock by P37 for T16A2 Ch.1
 *  -			MUX_EXCL6S_CH1_P50 : case use external clock by P50 for T16A2 Ch.1
 * -		useToutAPort; unsigned char : select ToutA port(only S1C17624)
 * 	-			MUX_TOUTAXP_OFF : case not use ToutA
 * 	-			MUX_TOUTA5P_CH0_P31 : case use ToutA5 by P31 for T16A2 Ch.0
 * 	-			MUX_TOUTA5P_CH0_P51 : case use ToutA5 by P51 for T16A2 Ch.0
 * 	-			MUX_TOUTA5P_CH0_P31_P51 : case use ToutA5 by P31 and P51 for T16A2 Ch.0
 * 	-			MUX_TOUTA6P_CH1_P33 : case use ToutA6 by P33 for T16A2 Ch.0
 * 	-			MUX_TOUTA6P_CH1_P55 : case use ToutA6 by P55 for T16A2 Ch.0
 * 	-			MUX_TOUTA6P_CH1_P33_P55 : case use ToutA6 by P33 and P55 for T16A2 Ch.0
 * -		useToutBPort; unsigned char : select ToutB port(only S1C17624)
 * 	-			MUX_TOUTBXP_OFF : case not use ToutB
 * 	-			MUX_TOUTB5P_CH0_P32 : case use ToutB5 by P32 for T16A2 Ch.0
 * 	-			MUX_TOUTB5P_CH0_P52 : case use ToutB5 by P52 for T16A2 Ch.0
 * 	-			MUX_TOUTB5P_CH0_P32_P52 : case use ToutB5 by P32 and P52 for T16A2 Ch.0
 * 	-			MUX_TOUTB6P_CH1_P34 : case use ToutB6 by P34 for T16A2 Ch.0
 * 	-			MUX_TOUTB6P_CH1_P56 : case use ToutB6 by P56 for T16A2 Ch.0
 * 	-			MUX_TOUTB6P_CH1_P34_P56 : case use ToutB6 by P34 and P56 for T16A2 Ch.0
 * @param	sw; unsigned char: 				select port function
 * -		MUX_OFF : set input/output ports
 * -		MUX_ON  : set 16-bit timer ports
 * @return	short:							end status
 * -		MUX_SUCCESS : success
 * -		MUX_INVALID_PARAMETER : invalid parameter
 * @date	2010/04/07
 */
short MUX_setT16A2port(unsigned char chNo, MUX_USE_T16A2PORT *use, unsigned char sw)
{

	// parameter check
	if(	(chNo >= T16A2_CH_MAX) ||
		(use->useEXCL > MUX_EXCL_ON) ||
		(use->useToutA > MUX_TOUTA_ON) ||
		(use->useToutB > MUX_TOUTB_ON) ||
#ifdef	S1C17624
		(use->useEXCLS >= MUX_EXCLXS_MAX) ||
		(use->useToutAPort >= MUX_TOUTAXP_MAX) ||
		(use->useToutBPort >= MUX_TOUTBXP_MAX) ||
#endif	// end of S1C17624
		(sw > MUX_ON) ) {
			return	MUX_INVALID_PARAMETER;
	}

#ifdef	S1C17624
	// PWM timer(T16A2) port set
	if(use->useToutA == MUX_TOUTA_ON) {
		switch(use->useToutAPort) {
		case	MUX_TOUTA5P_CH0_P31:
			RegModify(MUX_PORT_TOUTA5_0, MUX_MASK_TOUTA5_0, (MUX_T16A2_TOUTA5_0 * sw));
			break;
		case	MUX_TOUTA5P_CH0_P51:
			RegModify(MUX_PORT_TOUTA5_1, MUX_MASK_TOUTA5_1, (MUX_T16A2_TOUTA5_1 * sw));
			break;
		case	MUX_TOUTA5P_CH0_P31_P51:
			RegModify(MUX_PORT_TOUTA5_0, MUX_MASK_TOUTA5_0, (MUX_T16A2_TOUTA5_0 * sw));
			RegModify(MUX_PORT_TOUTA5_1, MUX_MASK_TOUTA5_1, (MUX_T16A2_TOUTA5_1 * sw));
			break;
		case	MUX_TOUTA6P_CH1_P33:
			RegModify(MUX_PORT_TOUTA6_0, MUX_MASK_TOUTA6_0, (MUX_T16A2_TOUTA6_0 * sw));
			break;
		case	MUX_TOUTA6P_CH1_P55:
			RegModify(MUX_PORT_TOUTA6_1, MUX_MASK_TOUTA6_1, (MUX_T16A2_TOUTA6_1 * sw));
			break;
		case	MUX_TOUTA6P_CH1_P33_P55:
			RegModify(MUX_PORT_TOUTA6_0, MUX_MASK_TOUTA6_0, (MUX_T16A2_TOUTA6_0 * sw));
			RegModify(MUX_PORT_TOUTA6_1, MUX_MASK_TOUTA6_1, (MUX_T16A2_TOUTA6_1 * sw));
			break;
		default:
			break;
		}
	}

	if(use->useToutB == MUX_TOUTB_ON) {
		switch(use->useToutBPort) {
		case	MUX_TOUTB5P_CH0_P32:
			RegModify(MUX_PORT_TOUTB5_0, MUX_MASK_TOUTB5_0, (MUX_T16A2_TOUTB5_0 * sw));
			break;
		case	MUX_TOUTB5P_CH0_P52:
			RegModify(MUX_PORT_TOUTB5_1, MUX_MASK_TOUTB5_1, (MUX_T16A2_TOUTB5_1 * sw));
			break;
		case	MUX_TOUTB5P_CH0_P32_P52:
			RegModify(MUX_PORT_TOUTB5_0, MUX_MASK_TOUTB5_0, (MUX_T16A2_TOUTB5_0 * sw));
			RegModify(MUX_PORT_TOUTB5_1, MUX_MASK_TOUTB5_1, (MUX_T16A2_TOUTB5_1 * sw));
			break;
		case	MUX_TOUTB6P_CH1_P34:
			RegModify(MUX_PORT_TOUTB6_0, MUX_MASK_TOUTB6_0, (MUX_T16A2_TOUTB6_0 * sw));
			break;
		case	MUX_TOUTB6P_CH1_P56:
			RegModify(MUX_PORT_TOUTB6_1, MUX_MASK_TOUTB6_1, (MUX_T16A2_TOUTB6_1 * sw));
			break;
		case	MUX_TOUTB6P_CH1_P34_P56:
			RegModify(MUX_PORT_TOUTB6_0, MUX_MASK_TOUTB6_0, (MUX_T16A2_TOUTB6_0 * sw));
			RegModify(MUX_PORT_TOUTB6_1, MUX_MASK_TOUTB6_1, (MUX_T16A2_TOUTB6_1 * sw));
			break;
		default:
			break;
		}
	}

	if(use->useEXCL == MUX_EXCL_ON) {
		switch(use->useEXCLS) {
		case	MUX_EXCL5S_CH0_P36:
			RegModify(MUX_PORT_EXCL5OUT_0, MUX_MASK_EXCL5OUT_0, MUX_T16A2_EXCL5OUT_0);
			RegModify(MUX_PORT_EXCL5IN_0, MUX_MASK_EXCL5IN_0, MUX_T16A2_EXCL5IN_0);
			RegModify(MUX_PORT_EXCL5_0, MUX_MASK_EXCL5_0, (MUX_T16A2_EXCL5_0 * sw));
			RegModify(R08_P5H_PMUX, EXCL5S, P36_EXCL5);
			break;
		case	MUX_EXCL5S_CH0_P47:
			RegModify(MUX_PORT_EXCL5OUT_1, MUX_MASK_EXCL5OUT_1, MUX_T16A2_EXCL5OUT_1);
			RegModify(MUX_PORT_EXCL5IN_1, MUX_MASK_EXCL5IN_1, MUX_T16A2_EXCL5IN_1);
			RegModify(MUX_PORT_EXCL5_1, MUX_MASK_EXCL5_1, (MUX_T16A2_EXCL5_1 * sw));
			RegModify(R08_P5H_PMUX, EXCL5S, P47_EXCL5);
			break;
		case	MUX_EXCL6S_CH1_P37:
			RegModify(MUX_PORT_EXCL6OUT_0, MUX_MASK_EXCL6OUT_0, MUX_T16A2_EXCL6OUT_0);
			RegModify(MUX_PORT_EXCL6IN_0, MUX_MASK_EXCL6IN_0, MUX_T16A2_EXCL6IN_0);
			RegModify(MUX_PORT_EXCL6_0, MUX_MASK_EXCL6_0, (MUX_T16A2_EXCL6_0 * sw));
			RegModify(R08_P5H_PMUX, EXCL6S, P37_EXCL6);
			break;
		case	MUX_EXCL6S_CH1_P50:
			RegModify(MUX_PORT_EXCL6OUT_1, MUX_MASK_EXCL6OUT_1, MUX_T16A2_EXCL6OUT_1);
			RegModify(MUX_PORT_EXCL6IN_1, MUX_MASK_EXCL6IN_1, MUX_T16A2_EXCL6IN_1);
			RegModify(MUX_PORT_EXCL6_1, MUX_MASK_EXCL6_1, (MUX_T16A2_EXCL6_1 * sw));
			RegModify(R08_P5H_PMUX, EXCL6S, P50_EXCL6);
			break;
		default:
			break;
		}
	}

#else	// S1C17622
	if(chNo == T16A2_CH0) {
		RegModify(MUX_PORT_TOUTA5_0, MUX_MASK_TOUTA5_0, (MUX_T16A2_TOUTA5_0 * sw));
		RegModify(MUX_PORT_TOUTB5_0, MUX_MASK_TOUTB5_0, (MUX_T16A2_TOUTB5_0 * sw));
		RegModify(MUX_PORT_EXCL5OUT_0, MUX_MASK_EXCL5OUT_0, MUX_T16A2_EXCL5OUT_0);
		RegModify(MUX_PORT_EXCL5IN_0, MUX_MASK_EXCL5IN_0, MUX_T16A2_EXCL5IN_0);
		RegModify(MUX_PORT_EXCL5_0, MUX_MASK_EXCL5_0, MUX_T16A2_EXCL5_0);
	} else {
		RegModify(MUX_PORT_TOUTA6_0, MUX_MASK_TOUTA6_0, (MUX_T16A2_TOUTA6_0 * sw));
		RegModify(MUX_PORT_TOUTB6_0, MUX_MASK_TOUTB6_0, (MUX_T16A2_TOUTB6_0 * sw));
		RegModify(MUX_PORT_EXCL6OUT_0, MUX_MASK_EXCL6OUT_0, MUX_T16A2_EXCL6OUT_0);
		RegModify(MUX_PORT_EXCL6IN_0, MUX_MASK_EXCL6IN_0, MUX_T16A2_EXCL6IN_0);
		RegModify(MUX_PORT_EXCL6_0, MUX_MASK_EXCL6_0, MUX_T16A2_EXCL6_0);
	}
#endif	// end of S1C17624

	return	MUX_SUCCESS;
}
#endif	// end of PE_T16A2

#endif	// end of PE_MUX
