/******************************************************************
 * mux.h
 *
 * MUX driver
 *
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef MUX_H_
#define MUX_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct mux_p03muxBitF {
	unsigned int	px0mux	: 2;
	unsigned int	px1mux	: 2;
	unsigned int	px2mux	: 2;
	unsigned int	px3mux	: 2;
};

struct mux_p47muxBitF {
	unsigned int	px4mux	: 2;
	unsigned int	px5mux	: 2;
	unsigned int	px6mux	: 2;
	unsigned int	px7mux	: 2;
};
#if	defined(S1C17624) || defined(S1C17622)
struct mux_p54_56muxBitF {
	unsigned int	px4mux	: 2;
	unsigned int	px5mux	: 2;
	unsigned int	px6mux	: 2;
#ifdef	S1C17624
	unsigned int	excl5s	: 1;
	unsigned int	excl6s	: 1;
#else	// S1C17622
	unsigned int			: 2;
#endif	// end of S1C17624
};

#endif	// end of S1C17624/S1C17622
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	MUX_BASE_ADDR						(BASE_ADDR+MUX_OFFSET)


/***********************************************
 ****** The Definition of Port MUX          ****
 ****** [Px]                                ****
 ***********************************************/
// P0 Port Function Select Register
#define	R08_P0L_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x00)
	#define	PX3MUX_SFT							6
	#define	PX2MUX_SFT							4
	#define	PX1MUX_SFT							2
	#define	PX0MUX_SFT							0
	#define	P03MUX								BIT(0x03, PX3MUX_SFT)		// P03 port function select
		#define	P03									BIT(0x00, PX3MUX_SFT)		// P03
		#define	xADTRG								BIT(0x01, PX3MUX_SFT)		// #ADTRG
	#define	P02MUX								BIT(0x03, PX2MUX_SFT)		// P02 port function select
		#define	P02									BIT(0x00, PX2MUX_SFT)		// P02/EXCL0(T16 Ch.0)
	#define	P01MUX								BIT(0x03, PX1MUX_SFT)		// P01 port function select
		#define	P01									BIT(0x00, PX1MUX_SFT)		// P01
		#define	REMI								BIT(0x01, PX1MUX_SFT)		// REMI
	#define	P00MUX								BIT(0x03, PX0MUX_SFT)		// P00 port function select
		#define	P00									BIT(0x00, PX0MUX_SFT)		// P00
		#define	REMO								BIT(0x01, PX0MUX_SFT)		// REMO

#ifdef	BIT_FIELD
#define P0_PMUX0_3							*(volatile unsigned char *)(BASE_ADDR+0x12a0)
#define BF_P0_PMUX0_3						(*(volatile struct mux_p03muxBitF *)(BASE_ADDR+0x12a0))
	#define P0_PMUX0_3_P03MUX					BF_P0_PMUX0_3.px3mux		// P03 port function select
	#define P0_PMUX0_3_P02MUX					BF_P0_PMUX0_3.px2mux		// P02 port function select
	#define P0_PMUX0_3_P01MUX					BF_P0_PMUX0_3.px1mux		// P01 port function select
	#define P0_PMUX0_3_P00MUX					BF_P0_PMUX0_3.px0mux		// P00 port function select
#endif	// end of BIT_FIELD


// P0 Port Function Select Register
#define	R08_P0H_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x01)
	#define	PX7MUX_SFT							6
	#define	PX6MUX_SFT							4
	#define	PX5MUX_SFT							2
	#define	PX4MUX_SFT							0
	#define	P07MUX								BIT(0x03, PX7MUX_SFT)		// P07 port function select
		#define	P07									BIT(0x00, PX7MUX_SFT)		// P07
		#define	xSPISS0								BIT(0x01, PX7MUX_SFT)		// #SPISS0
	#define	P06MUX								BIT(0x03, PX6MUX_SFT)		// P06 port function select
		#define	P06									BIT(0x00, PX6MUX_SFT)		// P06
		#define	SDI0								BIT(0x01, PX6MUX_SFT)		// SDI0
	#define	P05MUX								BIT(0x03, PX5MUX_SFT)		// P05 port function select
		#define	P05									BIT(0x00, PX5MUX_SFT)		// P05
		#define	SDO0								BIT(0x01, PX5MUX_SFT)		// SDO0
	#define	P04MUX								BIT(0x03, PX4MUX_SFT)		// P04 port function select
		#define	P04									BIT(0x00, PX4MUX_SFT)		// P04
		#define	SPICLK0								BIT(0x01, PX4MUX_SFT)		// SPICLK0

#ifdef	BIT_FIELD
#define P0_PMUX4_7							*(volatile unsigned char *)(BASE_ADDR+0x12a1)
#define BF_P0_PMUX4_7						(*(volatile struct mux_p47muxBitF *)(BASE_ADDR+0x12a1))
	#define P0_PMUX4_7_P07MUX					BF_P0_PMUX4_7.px7mux		// P07 port function select
	#define P0_PMUX4_7_P06MUX					BF_P0_PMUX4_7.px6mux		// P06 port function select
	#define P0_PMUX4_7_P05MUX					BF_P0_PMUX4_7.px5mux		// P05 port function select
	#define P0_PMUX4_7_P04MUX					BF_P0_PMUX4_7.px4mux		// P04 port function select
#endif	// end of BIT_FIELD


// P1 Port Function Select Register
#define	R08_P1L_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x02)
	#define	P13MUX								BIT(0x03, PX3MUX_SFT)		// P13 port function select
		#define	P13									BIT(0x00, PX3MUX_SFT)		// P13/EXCL1(T16 Ch.1)
		#define	AIN7								BIT(0x02, PX3MUX_SFT)		// AIN7
	#define	P12MUX								BIT(0x03, PX2MUX_SFT)		// P12 port function select
		#define	P12									BIT(0x00, PX2MUX_SFT)		// P12
		#define	SIN0								BIT(0x01, PX2MUX_SFT)		// SIN0
	#define	P11MUX								BIT(0x03, PX1MUX_SFT)		// P11 port function select
		#define	P11									BIT(0x00, PX1MUX_SFT)		// P11
		#define	SOUT0								BIT(0x01, PX1MUX_SFT)		// SOUT0
	#define	P10MUX								BIT(0x03, PX0MUX_SFT)		// P10 port function select
		#define	P10									BIT(0x00, PX0MUX_SFT)		// P10
		#define	SCLK0								BIT(0x01, PX0MUX_SFT)		// SCLK

#ifdef	BIT_FIELD
#define P1_PMUX0_3							*(volatile unsigned char *)(BASE_ADDR+0x12a2)
#define BF_P1_PMUX0_3						(*(volatile struct mux_p03muxBitF *)(BASE_ADDR+0x12a2))
	#define P1_PMUX0_3_P13MUX					BF_P1_PMUX0_3.px3mux		// P13 port function select
	#define P1_PMUX0_3_P12MUX					BF_P1_PMUX0_3.px2mux		// P12 port function select
	#define P1_PMUX0_3_P11MUX					BF_P1_PMUX0_3.px1mux		// P11 port function select
	#define P1_PMUX0_3_P10MUX					BF_P1_PMUX0_3.px0mux		// P10 port function select
#endif	// end of BIT_FIELD


// P1 Port Function Select Register
#define	R08_P1H_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x03)
	#define	P17MUX								BIT(0x03, PX7MUX_SFT)		// P17 port function select
		#define	P17									BIT(0x00, PX7MUX_SFT)		// P17
		#define	AIN3								BIT(0x01, PX7MUX_SFT)		// AIN3
	#define	P16MUX								BIT(0x03, PX6MUX_SFT)		// P16 port function select
		#define	P16									BIT(0x00, PX6MUX_SFT)		// P16
		#define	SCLK1_0								BIT(0x01, PX6MUX_SFT)		// SCLK1_0
		#define	AIN4								BIT(0x02, PX6MUX_SFT)		// AIN4
	#define	P15MUX								BIT(0x03, PX5MUX_SFT)		// P15 port function select
		#define	P15									BIT(0x00, PX5MUX_SFT)		// P15/EXCL3(T16E Ch.0)
		#define	AIN5								BIT(0x02, PX5MUX_SFT)		// AIN5
	#define	P14MUX								BIT(0x03, PX4MUX_SFT)		// P14 port function select
		#define	P14									BIT(0x00, PX4MUX_SFT)		// P14/EXCL2(T16 Ch.2)
		#define	AIN6								BIT(0x02, PX4MUX_SFT)		// AIN6

#ifdef	BIT_FIELD
#define P1_PMUX4_7							*(volatile unsigned char *)(BASE_ADDR+0x12a3)
#define BF_P1_PMUX4_7						(*(volatile struct mux_p47muxBitF *)(BASE_ADDR+0x12a3))
	#define P1_PMUX4_7_P17MUX					BF_P1_PMUX4_7.px7mux		// P17 port function select
	#define P1_PMUX4_7_P16MUX					BF_P1_PMUX4_7.px6mux		// P16 port function select
	#define P1_PMUX4_7_P15MUX					BF_P1_PMUX4_7.px5mux		// P15 port function select
	#define P1_PMUX4_7_P14MUX					BF_P1_PMUX4_7.px4mux		// P14 port function select
#endif	// end of BIT_FIELD


// P2 Port Function Select Register
#define	R08_P2L_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x04)
	#define	P23MUX								BIT(0x03, PX3MUX_SFT)		// P23 port function select
		#define	P23									BIT(0x00, PX3MUX_SFT)		// P23
		#define	SENB0								BIT(0x01, PX3MUX_SFT)		// SENB0
	#define	P22MUX								BIT(0x03, PX2MUX_SFT)		// P22 port function select
		#define	P22									BIT(0x00, PX2MUX_SFT)		// P22
		#define	AIN0								BIT(0x01, PX2MUX_SFT)		// AIN0
	#define	P21MUX								BIT(0x03, PX1MUX_SFT)		// P21 port function select
		#define	P21									BIT(0x00, PX1MUX_SFT)		// P21
		#define	AIN1								BIT(0x01, PX1MUX_SFT)		// AIN1
	#define	P20MUX								BIT(0x03, PX0MUX_SFT)		// P20 port function select
		#define	P20									BIT(0x00, PX0MUX_SFT)		// P20
		#define	AIN2								BIT(0x01, PX0MUX_SFT)		// AIN2

#ifdef	BIT_FIELD
#define P2_PMUX0_3							*(volatile unsigned char *)(BASE_ADDR+0x12a4)
#define BF_P2_PMUX0_3						(*(volatile struct mux_p03muxBitF *)(BASE_ADDR+0x12a4))
	#define P2_PMUX0_3_P23MUX					BF_P2_PMUX0_3.px3mux		// P23 port function select
	#define P2_PMUX0_3_P22MUX					BF_P2_PMUX0_3.px2mux		// P22 port function select
	#define P2_PMUX0_3_P21MUX					BF_P2_PMUX0_3.px1mux		// P21 port function select
	#define P2_PMUX0_3_P20MUX					BF_P2_PMUX0_3.px0mux		// P20 port function select
#endif	// end of BIT_FIELD


// P2 Port Function Select Register
#define	R08_P2H_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x05)
	#define	P27MUX								BIT(0x03, PX7MUX_SFT)		// P27 port function select
		#define	P27									BIT(0x00, PX7MUX_SFT)		// P27
		#define	SOUT1_0								BIT(0x01, PX7MUX_SFT)		// SOUT1_0
		#define	RFIN1								BIT(0x02, PX7MUX_SFT)		// RFIN1
	#define	P26MUX								BIT(0x01, PX6MUX_SFT)		// P26 port function select
		#define	P26									BIT(0x00, PX6MUX_SFT)		// P26
		#define	RFIN0								BIT(0x01, PX6MUX_SFT)		// RFIN0
	#define	P25MUX								BIT(0x01, PX5MUX_SFT)		// P25 port function select
		#define	P25									BIT(0x00, PX5MUX_SFT)		// P25
		#define	REF0								BIT(0x01, PX5MUX_SFT)		// REF0
	#define	P24MUX								BIT(0x03, PX4MUX_SFT)		// P24 port function select
		#define	P24									BIT(0x00, PX4MUX_SFT)		// P24
		#define	SENA0								BIT(0x01, PX4MUX_SFT)		// SENA0

#ifdef	BIT_FIELD
#define P2_PMUX4_7							*(volatile unsigned char *)(BASE_ADDR+0x12a5)
#define BF_P2_PMUX4_7						(*(volatile struct mux_p47muxBitF *)(BASE_ADDR+0x12a5))
	#define P2_PMUX4_7_P27MUX					BF_P2_PMUX4_7.px7mux		// P27 port function select
	#define P2_PMUX4_7_P26MUX					BF_P2_PMUX4_7.px6mux		// P26 port function select
	#define P2_PMUX4_7_P25MUX					BF_P2_PMUX4_7.px5mux		// P25 port function select
	#define P2_PMUX4_7_P24MUX					BF_P2_PMUX4_7.px4mux		// P24 port function select
#endif	// end of BIT_FIELD


// P3 Port Function Select Register
#define	R08_P3L_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x06)
	#define	P33MUX								BIT(0x03, PX3MUX_SFT)		// P33 port function select
		#define	P33									BIT(0x00, PX3MUX_SFT)		// P33
		#define	SCL1_0								BIT(0x01, PX3MUX_SFT)		// SCL1_0
		#define	SCL0_1								BIT(0x02, PX3MUX_SFT)		// SCL0_1
#if	defined(S1C17624) || defined(S1C17604)
		#define	TOUTA6_CAPA6_0						BIT(0x03, PX3MUX_SFT)		// TOUTA6/CAPA6_0
#endif	// end of S1C17624/S1C17604
	#define	P32MUX								BIT(0x03, PX2MUX_SFT)		// P32 port function select
		#define	P32									BIT(0x00, PX2MUX_SFT)		// P32
		#define	SDA0_0								BIT(0x01, PX2MUX_SFT)		// SDA0_0
		#define	SENB1								BIT(0x02, PX2MUX_SFT)		// SENB1
#if	defined(S1C17624) || defined(S1C17604)
		#define	TOUTB5_CAPB5_0						BIT(0x03, PX2MUX_SFT)		// TOUTB5/CAPB5_0
#endif	// end of S1C17624/S1C17604
	#define	P31MUX								BIT(0x03, PX1MUX_SFT)		// P31 port function select
		#define	P31									BIT(0x00, PX1MUX_SFT)		// P31
		#define	SCL0_0								BIT(0x01, PX1MUX_SFT)		// SCL0_0
		#define	SENA1								BIT(0x02, PX1MUX_SFT)		// SENA1
#if	defined(S1C17624) || defined(S1C17604)
		#define	TOUTA5_CAPA5_0						BIT(0x03, PX1MUX_SFT)		// TOUTA5/CAPA5_0
#endif	// end of S1C17624/S1C17604
	#define	P30MUX								BIT(0x03, PX0MUX_SFT)		// P30 port function select
		#define	P30									BIT(0x00, PX0MUX_SFT)		// P30
		#define	SIN1_0								BIT(0x01, PX0MUX_SFT)		// SIN1_0(UART)
		#define	REF1								BIT(0x02, PX0MUX_SFT)		// REF1

#ifdef	BIT_FIELD
#define P3_PMUX0_3							*(volatile unsigned char *)(BASE_ADDR+0x12a6)
#define BF_P3_PMUX0_3						(*(volatile struct mux_p03muxBitF *)(BASE_ADDR+0x12a6))
	#define P3_PMUX0_3_P33MUX					BF_P3_PMUX0_3.px3mux		// P33 port function select
	#define P3_PMUX0_3_P32MUX					BF_P3_PMUX0_3.px2mux		// P32 port function select
	#define P3_PMUX0_3_P31MUX					BF_P3_PMUX0_3.px1mux		// P31 port function select
	#define P3_PMUX0_3_P30MUX					BF_P3_PMUX0_3.px0mux		// P30 port function select
#endif	// end of BIT_FIELD


// P3 Port Function Select Register
#define	R08_P3H_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x07)
	#define	P37MUX								BIT(0x03, PX7MUX_SFT)		// P37 port function select
		#define	P37									BIT(0x00, PX7MUX_SFT)		// P37/EXCL6(T16A2 Ch.1)
		#define	TOUTN3								BIT(0x01, PX7MUX_SFT)		// TOUTN3
		#define	LFRO_0								BIT(0x02, PX7MUX_SFT)		// LFRO_0
		#define	TOUT4_0								BIT(0x03, PX7MUX_SFT)		// TOUT4_0
	#define	P36MUX								BIT(0x03, PX6MUX_SFT)		// P36 port function select
		#define	P36									BIT(0x00, PX6MUX_SFT)		// P36/EXCL5(T16A2 Ch.0)
		#define	TOUT3								BIT(0x01, PX6MUX_SFT)		// TOUT3
		#define	RFCLKO_0							BIT(0x02, PX6MUX_SFT)		// RFCLKO_0
	#define	P35MUX								BIT(0x03, PX5MUX_SFT)		// P35 port function select
		#define	P35									BIT(0x00, PX5MUX_SFT)		// P35
		#define	FOUT1								BIT(0x01, PX5MUX_SFT)		// FOUT1
		#define	xBFR_0								BIT(0x02, PX5MUX_SFT)		// #BFR_0
	#define	P34MUX								BIT(0x03, PX4MUX_SFT)		// P34 port function select
		#define	P34									BIT(0x00, PX4MUX_SFT)		// P34
		#define	SDA1_0								BIT(0x01, PX4MUX_SFT)		// SDA1_0
		#define	SDA0_1								BIT(0x02, PX4MUX_SFT)		// SDA0_1
#if	defined(S1C17624) || defined(S1C17604)
		#define	TOUTB6_CAPB6_0						BIT(0x03, PX4MUX_SFT)		// TOUTB6/CAPB6_0
#endif	// end of S1C17624/S1C17604


#ifdef	BIT_FIELD
#define P3_PMUX4_7							*(volatile unsigned char *)(BASE_ADDR+0x12a7)
#define BF_P3_PMUX4_7						(*(volatile struct mux_p47muxBitF *)(BASE_ADDR+0x12a7))
	#define P3_PMUX4_7_P37MUX					BF_P3_PMUX4_7.px7mux		// P37 port function select
	#define P3_PMUX4_7_P36MUX					BF_P3_PMUX4_7.px6mux		// P36 port function select
	#define P3_PMUX4_7_P35MUX					BF_P3_PMUX4_7.px5mux		// P35 port function select
	#define P3_PMUX4_7_P34MUX					BF_P3_PMUX4_7.px4mux		// P34 port function select
#endif	// end of BIT_FIELD


// P4 Port Function Select Register
#define	R08_P4L_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x08)
	#define	P43MUX								BIT(0x01, PX3MUX_SFT)		// P43 port function select
		#define	DCLK								BIT(0x00, PX3MUX_SFT)		// DCLK
		#define	P43									BIT(0x01, PX3MUX_SFT)		// P43
	#define	P42MUX								BIT(0x01, PX2MUX_SFT)		// P42 port function select
		#define	DST2								BIT(0x00, PX2MUX_SFT)		// DST2
		#define	P42									BIT(0x01, PX2MUX_SFT)		// P42
	#define	P41MUX								BIT(0x01, PX1MUX_SFT)		// P41 port function select
		#define	DSIO								BIT(0x00, PX1MUX_SFT)		// DSIO
		#define	P41									BIT(0x01, PX1MUX_SFT)		// P41
	#define	P40MUX								BIT(0x01, PX0MUX_SFT)		// P40 port function select
		#define	P40									BIT(0x00, PX0MUX_SFT)		// P40
		#define	FOUTH								BIT(0x01, PX0MUX_SFT)		// FOUTH

#ifdef	BIT_FIELD
#define P4_PMUX0_3							*(volatile unsigned char *)(BASE_ADDR+0x12a8)
#define BF_P4_PMUX0_3						(*(volatile struct mux_p03muxBitF *)(BASE_ADDR+0x12a8))
	#define P4_PMUX0_3_P43MUX					BF_P4_PMUX0_3.px3mux		// P43 port function select
	#define P4_PMUX0_3_P42MUX					BF_P4_PMUX0_3.px2mux		// P42 port function select
	#define P4_PMUX0_3_P41MUX					BF_P4_PMUX0_3.px1mux		// P41 port function select
	#define P4_PMUX0_3_P40MUX					BF_P4_PMUX0_3.px0mux		// P40 port function select
#endif	// end of BIT_FIELD


#if	defined(S1C17624) || defined(S1C17622)
#define	R08_P4H_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x09)
	#define	P47MUX								BIT(0x01, PX7MUX_SFT)		// P47 port function select
		#define	P47									BIT(0x00, PX7MUX_SFT)		// P47/EXCL5(T16A2 Ch.0)
		#define	TOUT4_1								BIT(0x01, PX7MUX_SFT)		// TOUT4_1
	#define	P46MUX								BIT(0x01, PX6MUX_SFT)		// P46 port function select
		#define	P46									BIT(0x00, PX6MUX_SFT)		// P46
		#define	RFCLKO_1							BIT(0x01, PX6MUX_SFT)		// RFCLKO_1
	#define	P45MUX								BIT(0x01, PX5MUX_SFT)		// P45 port function select
		#define	P45									BIT(0x00, PX5MUX_SFT)		// P45
		#define	SDA1_1								BIT(0x01, PX5MUX_SFT)		// SDA1_1
	#define	P44MUX								BIT(0x01, PX4MUX_SFT)		// P44 port function select
		#define	P44									BIT(0x00, PX4MUX_SFT)		// P40
		#define	SCL1_1								BIT(0x01, PX4MUX_SFT)		// SCL1_1

#ifdef	BIT_FIELD
#define P4_PMUX4_7							*(volatile unsigned char *)(BASE_ADDR+0x12a9)
#define BF_P4_PMUX4_7						(*(volatile struct mux_p47muxBitF *)(BASE_ADDR+0x12a9))
	#define P4_PMUX4_7_P47MUX					BF_P4_PMUX4_7.px7mux		// P47 port function select
	#define P4_PMUX4_7_P46MUX					BF_P4_PMUX4_7.px6mux		// P46 port function select
	#define P4_PMUX4_7_P45MUX					BF_P4_PMUX4_7.px5mux		// P45 port function select
	#define P4_PMUX4_7_P44MUX					BF_P4_PMUX4_7.px4mux		// P44 port function select
#endif	// end of BIT_FIELD


#define	R08_P5L_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x0a)
	#define	P53MUX								BIT(0x01, PX3MUX_SFT)		// P53 port function select
		#define	P53									BIT(0x00, PX3MUX_SFT)		// P53
		#define	xBFR_1								BIT(0x01, PX3MUX_SFT)		// #BFR_1
	#define	P52MUX								BIT(0x03, PX2MUX_SFT)		// P52 port function select
		#define	P52									BIT(0x00, PX2MUX_SFT)		// P52
		#define	SIN1_1								BIT(0x01, PX2MUX_SFT)		// SIN1_1
#ifdef	S1C17624
		#define	TOUTB5_CAPB5_1						BIT(0x02, PX2MUX_SFT)		// TOUTB5/CAPB5_1
#endif	// end of S1C17624
	#define	P51MUX								BIT(0x03, PX1MUX_SFT)		// P51 port function select
		#define	P51									BIT(0x00, PX1MUX_SFT)		// P51
		#define	SOUT1_1								BIT(0x01, PX1MUX_SFT)		// SOUT1_1
#ifdef	S1C17624
		#define	TOUTA5_CAPA5_1						BIT(0x02, PX1MUX_SFT)		// TOUTA5/CAPA5_1
#endif	// end of S1C17624
		#define	P50MUX							BIT(0x00, PX0MUX_SFT)		// P50 port function select
			#define	P50								BIT(0x00, PX0MUX_SFT)		// P50/EXCL6(T16A2 Ch.1)
			#define	SCLK1_1							BIT(0x01, PX0MUX_SFT)		// SCLK1_1

#ifdef	BIT_FIELD
#define P5_PMUX0_3							*(volatile unsigned char *)(BASE_ADDR+0x12aa)
#define BF_P5_PMUX0_3						(*(volatile struct mux_p03muxBitF *)(BASE_ADDR+0x12aa))
	#define P5_PMUX0_3_P53MUX					BF_P5_PMUX0_3.px3mux		// P53 port function select
	#define P5_PMUX0_3_P52MUX					BF_P5_PMUX0_3.px2mux		// P52 port function select
	#define P5_PMUX0_3_P51MUX					BF_P5_PMUX0_3.px1mux		// P51 port function select
	#define P5_PMUX0_3_P50MUX					BF_P5_PMUX0_3.px0mux		// P50 port function select
#endif	// end of BIT_FIELD


#define	R08_P5H_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x0b)
#ifdef	S1C17624
	#define	EXCL6S_SFT							7
	#define	EXCL5S_SFT							6
	#define	EXCL6S								BIT(0x01, EXCL6S_SFT)		// EXCL6 input select
		#define	P37_EXCL6							BIT(0x00, EXCL6S_SFT)		// P36/EXCL6
		#define	P50_EXCL6							BIT(0x01, EXCL6S_SFT)		// P50/EXCL6
	#define	EXCL5S								BIT(0x01, EXCL5S_SFT)		// EXCL5 input select
		#define	P36_EXCL5							BIT(0x00, EXCL5S_SFT)		// P37/EXCL5
	#define		P47_EXCL5							BIT(0x01, EXCL5S_SFT)		// P47/EXCL5
#endif	// end ofS1C17624
	#define	P56MUX								BIT(0x01, PX6MUX_SFT)		// P56 port function select
		#define	P56									BIT(0x00, PX6MUX_SFT)		// P56
#ifdef	S1C17624
		#define	TOUTB6_CAPB6_1						BIT(0x02, PX6MUX_SFT)		// TOUTB6/CAPB6_1
#endif	// S1C17624
	#define	P55MUX								BIT(0x01, PX5MUX_SFT)		// P55 port function select
		#define	P55									BIT(0x00, PX5MUX_SFT)		// P55
#ifdef	S1C17624
		#define	TOUTA6_CAPA6_1						BIT(0x02, PX5MUX_SFT)		// TOUTA6/CAPA6_1
#endif	// end of S1C17624
	#define	P54MUX								BIT(0x01, PX4MUX_SFT)		// P54 port function select
		#define	P54									BIT(0x00, PX4MUX_SFT)		// P54
		#define	LFRO_1								BIT(0x01, PX4MUX_SFT)		// LFRO_1

#ifdef	BIT_FIELD
#define P5_PMUX4_6							*(volatile unsigned char *)(BASE_ADDR+0x12ab)
#define BF_P5_PMUX4_6						(*(volatile struct mux_p54_56muxBitF *)(BASE_ADDR+0x12ab))
#ifdef	S1C17624
	#define P5_PMUX4_6_EXCL6S					BF_P5_PMUX4_6.excl6s		// EXCL6 input select
	#define P5_PMUX4_6_EXCL5S					BF_P5_PMUX4_6.excl5s		// EXCL5 input select
#endif	// end of S1C17624
	#define P5_PMUX4_6_P56MUX					BF_P5_PMUX4_6.px6mux		// P56 port function select
	#define P5_PMUX4_6_P55MUX					BF_P5_PMUX4_6.px5mux		// P55 port function select
	#define P5_PMUX4_6_P54MUX					BF_P5_PMUX4_6.px4mux		// P54 port function select
#endif	// end of BIT_FIELD

#endif	// end of S1C17624/S1C17622
#endif	// end of MUX_H_
