/******************************************************************
 * uart.h
 * 
 * UART driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef UART_H_
#define UART_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct uart_stBitF {
	unsigned int	tdbe	: 1;
	unsigned int	rdry	: 1;
	unsigned int	trbs	: 1;
	unsigned int	rd2b	: 1;
	unsigned int	oer		: 1;
	unsigned int	per		: 1;
	unsigned int	fer		: 1;
	unsigned int			: 1;
};

struct uart_modBitF {
	unsigned int	ssck	: 1;
	unsigned int	stpb	: 1;
	unsigned int	pmd		: 1;
	unsigned int	pren	: 1;
	unsigned int	chln	: 1;
	unsigned int			: 3;
};

struct uart_ctlBitF {
	unsigned int	rxen	: 1;
	unsigned int	rbfi	: 1;
	unsigned int			: 2;
	unsigned int	tien	: 1;
	unsigned int	rien	: 1;
	unsigned int	reien	: 1;
	unsigned int			: 1;
};

struct uart_expBitF {
	unsigned int	irmd	: 1;
	unsigned int			: 3;
	unsigned int	irclk	: 3;
	unsigned int			: 1;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	UART_BASE_ADDR						(BASE_ADDR+UART_OFFSET)


/***********************************************
 ****** The Definition of UART      ************
 ****** [UART]                      ************
 ***********************************************/
// UART Ch.x Status Register
// NOTE : The writing that used the bit field inhibits.
#define	R08_UART_ST(ch)						(volatile unsigned char *)(unsigned long)(UART_BASE_ADDR+0x00+(ch*UART_CHOFFSET))
	#define	FER_SFT								6
	#define	PER_SFT								5
	#define	OER_SFT								4
	#define	RD2B_SFT							3
	#define	TRBS_SFT							2
	#define	RDRY_SFT							1
	#define	TDBE_SFT							0
	#define	FER									BIT(0x01, FER_SFT)			// Framing error flag
		#define	UART_NORMAL							0x00						// normal
		#define	UART_ERROR							0x01						// error
		#define	UART_INVALID						0x00						// invalid
		#define	UART_RESET							0x01						// reset
	#define	PER									BIT(0x01, PER_SFT)			// Parity error flag
	#define	OER									BIT(0x01, OER_SFT)			// Overrun error flag
		#define	UART_REIEN_MASK						(FER | PER | OER)			// receive error interrupt mask data
	#define	RD2B								BIT(0x01, RD2B_SFT)			// Second byte received flag
		#define	UART_RXEMPTY						0x00						// receive empty
		#define	UART_RXREADY						0x01						// receive ready
	#define	TRBS								BIT(0x01, TRBS_SFT)			// Transmit busy flag
		#define	UART_IDLE							0x00						// idle
		#define	UART_BUSY							0x01						// busy
	#define	RDRY								BIT(0x01, RDRY_SFT)			// Receive data ready flag
	#define	TDBE								BIT(0x01, TDBE_SFT)			// Transmit data buffer empty flag
		#define	UART_NOTEMPTY						0x00						// not empty
		#define	UART_EMPTY							0x01						// empty

#ifdef	BIT_FIELD
#define UART_ST0							*(volatile unsigned char *)(BASE_ADDR+0x0100)
#define BF_UART_ST0							(*(volatile struct uart_stBitF *)(BASE_ADDR+0x0100))
	#define UART_ST0_FER						BF_UART_ST0.fer				// Framing error flag
	#define UART_ST0_PER						BF_UART_ST0.per				// Parity error flag
	#define UART_ST0_OER						BF_UART_ST0.oer				// Overrun error flag
	#define UART_ST0_RD2B						BF_UART_ST0.rd2b			// Second byte receive flag
	#define UART_ST0_TRBS						BF_UART_ST0.trbs			// Transmit busy flag
	#define UART_ST0_RDRY						BF_UART_ST0.rdry			// Receive data ready flag
	#define UART_ST0_TDBE						BF_UART_ST0.tdbe			// Transmit data buffer empty flag

#define UART_ST1							*(volatile unsigned char *)(BASE_ADDR+0x0120)
#define BF_UART_ST1							(*(volatile struct uart_stBitF *)(BASE_ADDR+0x0120))
	#define UART_ST1_FER						BF_UART_ST1.fer				// Framing error flag
	#define UART_ST1_PER						BF_UART_ST1.per				// Parity error flag
	#define UART_ST1_OER						BF_UART_ST1.oer				// Overrun error flag
	#define UART_ST1_RD2B						BF_UART_ST1.rd2b			// Second byte receive flag
	#define UART_ST1_TRBS						BF_UART_ST1.trbs			// Transmit busy flag
	#define UART_ST1_RDRY						BF_UART_ST1.rdry			// Receive data ready flag
	#define UART_ST1_TDBE						BF_UART_ST1.tdbe			// Transmit data buffer empty flag
#endif	// end of BIT_FIELD


// UART Ch.x Transmit Data Register
#define	R08_UART_TXD(ch)					(volatile unsigned char *)(unsigned long)(UART_BASE_ADDR+0x01+(ch*UART_CHOFFSET))

#ifdef	BIT_FIELD
#define UART_TXD0							*(volatile unsigned char *)(BASE_ADDR+0x0101)
	#define UART_TXD0_TXD						UART_TXD0					// Transmit data

#define UART_TXD1							*(volatile unsigned char *)(BASE_ADDR+0x0121)
	#define UART_TXD1_TXD						UART_TXD1					// Transmit data
#endif	// end of BIT_FIELD


// UART Ch.x Receive Data Register
#define	R08_UART_RXD(ch)					(volatile unsigned char *)(unsigned long)(UART_BASE_ADDR+0x02+(ch*UART_CHOFFSET))

#ifdef	BIT_FIELD
#define UART_RXD0							*(volatile unsigned char *)(BASE_ADDR+0x0102)
	#define UART_RXD0_RXD						UART_RXD0					// Receive data in the recive data buffer

#define UART_RXD1							*(volatile unsigned char *)(BASE_ADDR+0x0122)
	#define UART_RXD1_RXD						UART_RXD1					// Receive data in the recive data buffer
#endif	// end of BIT_FIELD


// UART Ch.x Mode Register
#define	R08_UART_MOD(ch)					(volatile unsigned char *)(unsigned long)(UART_BASE_ADDR+0x03+(ch*UART_CHOFFSET))
	#define	CHLN_SFT							4
	#define	PREN_SFT							3
	#define	PMD_SFT								2
	#define	STPB_SFT							1
	#define	SSCK_SFT							0
	#define	CHLN								BIT(0x01, CHLN_SFT)			// Character length
		#define	UART_7BIT							0x00						// 7-bit
		#define	UART_8BIT							0x01						// 8-bit
	#define	PREN								BIT(0x01, PREN_SFT)			// Parity enable
		#define	UART_NO_PARITY						0x00						// no parity
		#define	UART_WITH_PARITY					0x01						// with parity
	#define	PMD									BIT(0x01, PMD_SFT)			// Parity mode select
		#define	UART_EVEN							0x00						// even parity
		#define	UART_ODD							0x01						// odd parity
	#define	STPB								BIT(0x01, STPB_SFT)			// Stop bit select
		#define	UART_1BIT							0x00						// 1-bit
		#define	UART_2BIT							0x01						// 2-bit
	#define	SSCK								BIT(0x01, SSCK_SFT)			// Input clock select
		#define	UART_INTERNAL						0x00						// internal
		#define	UART_EXTERNAL						0x01						// external

#ifdef	BIT_FIELD
#define UART_MOD0							*(volatile unsigned char *)(BASE_ADDR+0x0103)
#define BF_UART_MOD0						(*(volatile struct uart_modBitF *)(BASE_ADDR+0x0103))
	#define UART_MOD0_CHLN						BF_UART_MOD0.chln			// Character length
	#define UART_MOD0_PREN						BF_UART_MOD0.pren			// Parity enable
	#define UART_MOD0_PMD						BF_UART_MOD0.pmd			// Parity mode select
	#define UART_MOD0_STPB						BF_UART_MOD0.stpb			// Stop bit select
	#define UART_MOD0_SSCK						BF_UART_MOD0.ssck			// Input clock select

#define UART_MOD1							*(volatile unsigned char *)(BASE_ADDR+0x0123)
#define BF_UART_MOD1						(*(volatile struct uart_modBitF *)(BASE_ADDR+0x0123))
	#define UART_MOD1_CHLN						BF_UART_MOD1.chln			// Character length
	#define UART_MOD1_PREN						BF_UART_MOD1.pren			// Parity enable
	#define UART_MOD1_PMD						BF_UART_MOD1.pmd			// Parity mode select
	#define UART_MOD1_STPB						BF_UART_MOD1.stpb			// Stop bit select
	#define UART_MOD1_SSCK						BF_UART_MOD1.ssck			// Input clock select
#endif	// end of BIT_FIELD


// UART Ch.x Control Register
#define	R08_UART_CTL(ch)					(volatile unsigned char *)(unsigned long)(UART_BASE_ADDR+0x04+(ch*UART_CHOFFSET))
	#define	REIEN_SFT							6
	#define	RIEN_SFT							5
	#define	TIEN_SFT							4
	#define	RBFI_SFT							1
	#define	RXEN_SFT							0
	#define	REIEN								BIT(0x01, REIEN_SFT)		// Receive error interrupt enable
		#define	UART_DISABLE						0x00						// disable
		#define	UART_ENABLE							0x01						// enable
	#define	RIEN								BIT(0x01, RIEN_SFT)			// Receive buffer full interrupt enable
	#define	TIEN								BIT(0x01, TIEN_SFT)			// Transmit buffer empty interrupt enable
		#define	UART_IEN_MASK						(REIEN | RIEN | TIEN)		// interrupt mask data
	#define	RBFI								BIT(0x01, RBFI_SFT)			// Receive buffer full interrupt condition
		#define	UART_1BYTE							0x00						// 1-byte
		#define	UART_2BYTE							0x01						// 2-byte
	#define	RXEN								BIT(0x01, RXEN_SFT)			// UART enable

#ifdef	BIT_FIELD
#define UART_CTL0							*(volatile unsigned char *)(BASE_ADDR+0x0104)
#define BF_UART_CTL0						(*(volatile struct uart_ctlBitF *)(BASE_ADDR+0x0104))
	#define UART_CTL0_REIEN						BF_UART_CTL0.reien			// Receive error int. enable
	#define UART_CTL0_RIEN						BF_UART_CTL0.rien			// Receive buffer full int. enable
	#define UART_CTL0_TIEN						BF_UART_CTL0.tien			// Transmit buffer empty int. enable
	#define UART_CTL0_RBFI						BF_UART_CTL0.rbfi			// Receive buffer full int. condition
	#define UART_CTL0_RXEN						BF_UART_CTL0.rxen			// UART enable

#define UART_CTL1							*(volatile unsigned char *)(BASE_ADDR+0x0124)
#define BF_UART_CTL1						(*(volatile struct uart_ctlBitF *)(BASE_ADDR+0x0124))
	#define UART_CTL1_REIEN						BF_UART_CTL1.reien			// Receive error int. enable
	#define UART_CTL1_RIEN						BF_UART_CTL1.rien			// Receive buffer full int. enable
	#define UART_CTL1_TIEN						BF_UART_CTL1.tien			// Transmit buffer empty int. enable
	#define UART_CTL1_RBFI						BF_UART_CTL1.rbfi			// Receive buffer full int. condition
	#define UART_CTL1_RXEN						BF_UART_CTL1.rxen			// UART enable
#endif	// end of BIT_FIELD


// UART Ch.x Expansion Register
#define	R08_UART_EXP(ch)					(volatile unsigned char *)(unsigned long)(UART_BASE_ADDR+0x05+(ch*UART_CHOFFSET))
	#define	IRCLK_SFT							4
	#define	IRMD_SFT							0
	#define	IRCLK								BIT(0x07, IRCLK_SFT)		// IrDA receive detection clock select
	#define	IRMD								BIT(0x01, IRMD_SFT)			// IrDA mode select
		#define	UART_OFF							0x00						// off
		#define	UART_ON								0x01						// on

#ifdef	BIT_FIELD
#define UART_EXP0							*(volatile unsigned char *)(BASE_ADDR+0x0105)
#define BF_UART_EXP0						(*(volatile struct uart_expBitF *)(BASE_ADDR+0x0105))
	#define UART_EXP0_IRCLK						BF_UART_EXP0.irclk			// IrDA receive detection clock select
	#define UART_EXP0_IRMD						BF_UART_EXP0.irmd			// IrDA mode select

#define UART_EXP1							*(volatile unsigned char *)(BASE_ADDR+0x0125)
#define BF_UART_EXP1						(*(volatile struct uart_expBitF *)(BASE_ADDR+0x0125))
	#define UART_EXP1_IRCLK						BF_UART_EXP1.irclk			// IrDA receive detection clock select
	#define UART_EXP1_IRMD						BF_UART_EXP1.irmd			// IrDA mode select
#endif	// end of BIT_FIELD


#endif	// end of UART_H_
