/******************************************************************
 * boot.c
 *
 * This is vector and interrupt program with C.
 *
 * Copyright(C) SEIKO EPSON CORPORATION 2010. All rights Reserved.
 *****************************************************************/

#include <string.h>
#include <libstdio.h>
#include <misc_api.h>
#if defined(S1C17604) || defined(S1C17624)
#include <ct_api.h>
#include <rtc_api.h>
#endif	// end of S1C17604/S1C17624
/******************************************
 * Declarations of function prototype
 ******************************************/
void boot(void);
void ClearBss(void);
void CopyLmaToVma(void);
void end(void);
void dummy(void)__attribute__ ((interrupt_handler));
void nmi(void)__attribute__ ((interrupt_handler));
void emu_copro_process(void)__attribute__ ((interrupt_handler));

/******************************************
 * extern
 ******************************************/
extern int main(void);
#ifdef	PE_PORT
extern void portIntP0xHandler(void)__attribute__ ((interrupt_handler));
extern void portIntP1xHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_PORT
#ifdef	PE_SWT
extern void swtIntHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_SWT
#ifdef	PE_CT
#ifdef	PE_RTC
void ct_rtcSwitchIntHandler(void)__attribute__ ((interrupt_handler));
extern void ctInt(void);
extern void rtcInt(void);
#else
extern void ctIntHandler(void)__attribute__ ((interrupt_handler));
#endif // end of PE_RTC
#else
#ifdef	PE_RTC
extern void rtcIntHandler(void)__attribute__ ((interrupt_handler));
#endif // end of PE_RTC
#endif	// end of PE_CT
#ifdef	PE_T8OSC1
extern void t8oIntHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_T8OSC1
#ifdef	PE_SVD
extern void svdIntHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_SVD
#ifdef	PE_T16E
extern void t16eIntHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_T16E
#ifdef	PE_T8F
extern void t8fIntHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_T8F
#ifdef	PE_T16
extern void t16IntHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_T16
#ifdef	PE_UART
extern void uartIntHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_UART
#ifdef	PE_I2CS
extern void i2cSlaveIntHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_I2CS
#ifdef	PE_SPI
extern void spiIntHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_SPI
#ifdef	PE_I2CM
extern void i2cMasterIntHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_I2CM
#ifdef	PE_REMC
extern void remcIntHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_REMC
#ifdef	PE_ADC
extern void adcIntHandler(void)__attribute__ ((interrupt_handler));
#endif	// end of PE_ADC
#ifdef	PE_RFC
extern void rfcIntHandler(void)__attribute__ ((interrupt_handler));
#endif	// PE_RFC
#ifdef	PE_T16A2
extern void t16a2IntHandler(void)__attribute__ ((interrupt_handler));
#endif // end of PE_T16A2

extern unsigned long __START_bss;
extern unsigned long __END_bss;
extern unsigned long __START_data;
extern unsigned long __START_data_lma;
extern unsigned long __END_data;
extern unsigned long __START_simio;
extern unsigned long __START_simio_lma;
extern unsigned long __END_simio;

/******************************************
 * special definitions for vector table
 ******************************************/
typedef void func(void);
#ifdef __POINTER16
#define VECTOR(vec)  (vec),0
#else
#define VECTOR(vec)  (vec)
#endif

/******************************************
 * vector table
 ******************************************/
func *const vector[] = {		// No	Base+	Name
	VECTOR(boot),				// 0	00		Reset
	VECTOR(dummy),				// 1	04		Illegal Adress Int.
	VECTOR(nmi),				// 2	08		NMI
	VECTOR(emu_copro_process),	// 3	0c		copro precess
#ifdef	PE_PORT
	VECTOR(portIntP0xHandler),	// 4	10		P0X Int.
	VECTOR(portIntP1xHandler),	// 5	14		P1X Int.
#else
	VECTOR(0),					// 4	10		P0X Int.
	VECTOR(0),					// 5	14		P1X Int.
#endif	// end of PE_PORT
#ifdef	PE_SWT
	VECTOR(swtIntHandler),		// 6	18		SWT Int.
#else
	VECTOR(0),					// 6	18		SWT Int.
#endif	// end of PE_SWT
#ifdef	PE_CT
#ifdef	PE_RTC
	VECTOR(ct_rtcSwitchIntHandler),	// 7	1c		CT/RTC Int.
#else
	VECTOR(ctIntHandler),		// 7	1c		CT/RTC Int.
#endif // end of PE_RTC
#else
#ifdef	PE_RTC
	VECTOR(rtcIntHandler),		// 7	1c		CT/RTC Int.
#else
	VECTOR(0),					// 7	1c		CT/RTC Int.
#endif // end of PE_RTC
#endif	// end of PE_CT
#ifdef	PE_T8OSC1
	VECTOR(t8oIntHandler),		// 8	20		T8OSC1 Int.
#else
	VECTOR(0),					// 8	20		T8OSC1 Int.
#endif	// end of PE_T8OSC1
#ifdef	PE_SVD
	VECTOR(svdIntHandler),		// 9	24		SVD Int.
#else
	VECTOR(0),					// 9	24		SVD Int.
#endif	// end of PE_SVD
#ifdef	PE_T16A2
	VECTOR(t16a2IntHandler),	// 10	28		LCD/T16A2 Ch.0 Int.
#else
	VECTOR(0),					// 10	28		LCD/T16A2 Ch.0 Int.
#endif // end of PE_T16A2
#ifdef	PE_T16E
	VECTOR(t16eIntHandler),		// 11	2c		PWM Ch.0 Int.
#else
	VECTOR(0),					// 11	2c		PWM Ch.0 Int.
#endif	// end of PE_T16E
#ifdef	PE_T8F
	VECTOR(t8fIntHandler),		// 12	30		T8F Int.
#else
	VECTOR(0),					// 12	30		T8F Int.
#endif	// end of PE_T8F
#ifdef	PE_T16
	VECTOR(t16IntHandler),		// 13	34		T16 Ch.0 Int.
#else
	VECTOR(0),					// 13	34		T16 Ch.0 Int.
#endif	// end of PE_T16
	VECTOR(0),					// 14	38		T16 Ch.1 Int.
	VECTOR(0),					// 15	3c		T16 Ch.2 Int.
#ifdef	PE_UART
	VECTOR(uartIntHandler),		// 16	40		UART Ch.0 Int.
#else
	VECTOR(0),					// 16	40		UART Ch.0 Int.
#endif	// end of PE_UART
#ifdef	PE_I2CS
	VECTOR(i2cSlaveIntHandler),	// 17	44		I2C slave Int.
#else
	VECTOR(0),					// 17	44		I2C slave Int.
#endif	// end of PE_I2CS
#ifdef	PE_SPI
	VECTOR(spiIntHandler),		// 18	48		SPI Int.
#else
	VECTOR(0),					// 18	48		SPI Int.
#endif	// end of PE_SPI
#ifdef	PE_I2CM
	VECTOR(i2cMasterIntHandler),// 19	4c		I2C master Int.
#else
	VECTOR(0),					// 19	4c		I2C master Int.
#endif	// end of PE_I2CM
#ifdef	PE_REMC
	VECTOR(remcIntHandler),		// 20	50		REMC Int.
#else
	VECTOR(0),					// 20	50		REMC Int.
#endif	// end of PE_REMC
	VECTOR(0),					// 21	54		reserved
#ifdef	PE_ADC
	VECTOR(adcIntHandler),		// 22	58		ADC Int
#else
	VECTOR(0),					// 22	58		ADC Int
#endif	// end of PE_ADC
#ifdef	PE_RFC
	VECTOR(rfcIntHandler),		// 23	5c		RFC Int
#else
	VECTOR(0),					// 23	5c		RFC Int
#endif	// PE_RFC
	VECTOR(0),					// 24	60		reserved
	VECTOR(0),					// 25	64		reserved
	VECTOR(0),					// 26	68		reserved
	VECTOR(0),					// 27	6c		reserved
	VECTOR(0),					// 28	70		reserved
	VECTOR(0),					// 29	74		reserved
	VECTOR(0),					// 30	78		reserved
	VECTOR(0),					// 31	7c		reserved
};


/*
 * Boot function.
 * First, this function turns off the "DSI noise filter".
 * Next, it resets the Stack Pointer, clear the bss area, and copy LMA to VMA.
 * Then, it calls "main" function and calls "end" function.
 * param: void
 * return: void
 * history: 2009/12/25
 */
void boot(void)
{
#if defined(S1C17624) || defined(S1C17604)
	asm ("xld.a  %sp, 0x1fc0");		// Set SP in RAM
#else	// S1C17622
	asm ("xld.a  %sp, 0x0fc0");		// Set SP in RAM
#endif	// end of S1C17624/S1C17604


	ClearBss();						// clear the bss area
	CopyLmaToVma();					// copy LMA data to VMA data
    _init_sys();					// Initialize for sys.c
    _init_lib();					// Initialize for lib.c

	MISC_setFlashReadAccessCycle(MISC_READ_CYCLE1);

#if	defined(S1C17604) || defined(S1C17624)
	RTC_controlInt(RTC_INT_DISABLE);				// disable RTC interrupt
#else	// S1C17622
	asm("ld	    %r0, 0x01");
	asm("xld.b  [0x5140], %r0");					// set 0x01 to [0x5140]
	asm("ld	    %r0, 0x06");
	asm("xld.b  [0x5141], %r0");					// set 0x06 to [0x5141]
#endif	// end of S1C17604/S1C17624

	asm ("ei");						//interrupt enable

	main(); 						// Call main
	end(); 							// Call end
}

/*
 * ClearBss function.
 * This function clears the bss area.
 * param: void
 * return: void
 * history: 2009/12/25
 */
void ClearBss(void)
{
	unsigned long ulCnt;			// counter
	unsigned char *pcData;			// clear address

	pcData = (unsigned char *)&__START_bss;
	for(ulCnt = 0; ulCnt < ((unsigned char *)&__END_bss - (unsigned char *)&__START_bss); ulCnt++) {
		*pcData = 0;
		pcData++;
	}
}

/*
 * CopyLmaToVma function.
 * This function copys LMA data to VMA data.
 * param: void
 * return: void
 * history: 2009/12/25
 */
void CopyLmaToVma(void)
{
	memcpy( (unsigned char *)&__START_data,
			(unsigned char *)&__START_data_lma,
			((unsigned char *)&__END_data - (unsigned char *)&__START_data) );
	memcpy( (unsigned char *)&__START_simio,
			(unsigned char *)&__START_simio_lma,
			((unsigned char *)&__END_simio - (unsigned char *)&__START_simio) );
}

/*
 * End function.
 * This function has only infinite loop.
 * param: void
 * return: void
 * history: 2009/12/25
 */
void end(void)
{
	// infinite loop
	while(1) {
		;
	}
}

/*
 * Non Maskable Interrupt function.
 * param: void
 * return: void
 * history: 2009/12/25
 */
void nmi(void)
{
	// Processing is undecided.
	;
}

/*
 * Dummy Interrupt function.
 * This function has only infinite loop.
 * param: void
 * return: void
 * history: 2009/12/25
 */
void dummy(void)
{
	// infinite loop
	while(1) {
		;
	}
}

#if defined(S1C17604) || defined(S1C17624)
/*
 * CT and RTC common Interrupt function.
 * This function switch call function by interrupt flag.
 * param: void
 * return: void
 * history: 2010/04/05
 */
void ct_rtcSwitchIntHandler(void)
{
	unsigned char	flgIntr;		// interrupt flag

	// get RTC interrupt status
	RTC_checkIntFlag(&flgIntr);
	if(flgIntr != 0) {
		rtcInt();
	} else {
		// get CT interrupt status
		CT_checkIntFlag(&flgIntr);
		if(flgIntr != 0) {
			ctInt();
		}
	}
}
#endif // end of S1C17604/S1C17624
